@@ -292,6 +292,12 @@ pref("mail.operate_on_msgs_in_collapsed_threads", true);
 pref("mail.warn_on_collapsed_thread_operation", true);
 pref("mail.warn_on_shift_delete", true);
 
+// When using commands like "next message" or "previous message", leave
+// at least this many visible rows above or below the selected message
+// in the thread pane.
+pref("mail.threadpane.padding.top", 1);
+pref("mail.threadpane.padding.bottom", 1);
+
 // only affects cookies from RSS articles
 // 0-Accept, 1-dontAcceptForeign, 2-dontUse
 pref("network.cookie.cookieBehavior", 0);
@@ -471,7 +477,11 @@ pref("mail.tabs.closeWindowWithLastTab", true);
 pref("mail.tabs.closeButtons", 1);
 
 // Allow the tabs to be in the titlebar on supported systems
+#ifdef XP_MACOSX
+pref("mail.tabs.drawInTitlebar", false);
+#else
 pref("mail.tabs.drawInTitlebar", true);
+#endif
 
 // The breakpad report server to link to in about:crashes
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
@@ -691,6 +701,11 @@ pref("browser.chrome.favicons", true);
 // something sensible should an extension wish to enable this.
 pref("places.history.enabled", false);
 
+// With places disabled by default, the default growth increment is set to zero
+// as it would otherwise default to 10MB as the minimum space occupied by the
+// places.sqlite database in the profile.
+pref("places.database.growthIncrementKiB", 0);
+
 // The percentage of system memory that the Places database can use.  Out of the
 // allowed cache size it will at most use the size of the database file.
 // Changes to this value are effective after an application restart.
