@@ -5,6 +5,7 @@
 
 Components.utils.import("resource:///modules/mailServices.js");
 Components.utils.import("resource:///modules/appIdleManager.js");
+Components.utils.import("resource:///modules/MailUtils.js");
 Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource:///modules/gloda/log4moz.js");
@@ -160,13 +161,6 @@ nsMsgStatusFeedback.prototype =
       this.showStatusString(status);
   },
 
-  setJSDefaultStatus: function(status) {
-    if (status.length > 0) {
-      this._defaultStatusText = status;
-      this._statusText.label = status;
-    }
-  },
-
   setOverLink: function(link, context) {
     this._statusText.label = link;
   },
@@ -196,6 +190,13 @@ nsMsgStatusFeedback.prototype =
     this._statusText.label = statusText;
   },
 
+  setStatusString: function(status) {
+    if (status.length > 0) {
+      this._defaultStatusText = status;
+      this._statusText.label = status;
+    }
+  },
+
   _startMeteors: function() {
     this._meteorsSpinning = true;
     this._startTimeoutID = null;
@@ -229,7 +230,7 @@ nsMsgStatusFeedback.prototype =
   },
 
   _stopMeteors: function() {
-    this.showStatusString(defaultStatus);
+    this.showStatusString(this._defaultStatusText);
 
     // stop the throbber
     if (this._throbber)
@@ -402,7 +403,7 @@ nsMsgWindowCommands.prototype =
 
   selectFolder: function(folderUri)
   {
-    gFolderTreeView.selectFolder(GetMsgFolderFromUri(folderUri));
+    gFolderTreeView.selectFolder(MailUtils.getFolderForURI(folderUri));
   },
 
   selectMessage: function(messageUri)
