@@ -1,41 +1,6 @@
-/* ***** BEGIN LICENSE BLOCK *****
- *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Thunderbird Mail Client.
- *
- * The Initial Developer of the Original Code is
- * the Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2011
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Blake Winton <bwinton@latte.ca>
- *   Dan Mosedale <dmose@mozillamessaging.com>
- *   Joachim Herb <Joachim.Herb@gmx.de>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /*
  * Test that we can add a tag to a message without messing up the header.
@@ -53,6 +18,8 @@ Cu.import("resource://gre/modules/Services.jsm");
 
 var folder;
 var gCDHelper ;
+var originalPaneLayout;
+const kPaneLayout = "mail.pane_config.dynamic";
 
 function setupModule(module) {
   let fdh = collector.getModule('folder-display-helpers');
@@ -66,7 +33,7 @@ function setupModule(module) {
   let cu = collector.getModule('customization-helpers');
   cu.installInto(module);
   gCDHelper = new CustomizeDialogHelper('header-view-toolbar',
-    'CustomizeHeaderToolbar', 'CustomizeToolbarWindow');
+    'CustomizeHeaderToolbar', "mailnews:customizeToolbar");
 
   folder = create_folder("HeaderToolbar");
 
@@ -89,6 +56,18 @@ function setupModule(module) {
   add_message_to_folder(folder, msg);
 }
 
+function setWideView() {
+  originalPaneLayout = Services.prefs.getIntPref(kPaneLayout);
+  Services.prefs.setIntPref(kPaneLayout, 1);
+}
+
+function restoreOriginalPaneLayout() {
+  Services.prefs.setIntPref(kPaneLayout, originalPaneLayout);
+}
+
+function teardownModule(module) {
+  restoreOriginalPaneLayout();
+}
 
 /**
  *  Make sure that opening the header toolbar customization dialog
@@ -168,6 +147,9 @@ function test_customize_header_toolbar_check_default()
  */
 function test_customize_header_toolbar_reorder_buttons()
 {
+  // To avoid undrawn buttons on the toolbar, change pane layout to wide view.
+  setWideView();
+
   let curMessage = select_message_in_folder(0);
 
   // Restore the default buttons to get defined starting conditions.
@@ -207,6 +189,8 @@ function test_customize_header_toolbar_reorder_buttons()
   assert_equals(hdrToolbar.getAttribute("currentset"), hdrBarDefaultSet);
   close_window(msgc);
 
+  restoreOriginalPaneLayout();
+
   // Leave the toolbar in the default state.
   gCDHelper.restoreDefaultButtons(mc);
 }
