@@ -2,9 +2,13 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var Ci = Components.interfaces;
-var Cc = Components.classes;
-var Cu = Components.utils;
+const MODULE_NAME = "compose-helpers";
+
+const RELATIVE_ROOT = "../shared-modules";
+// we need this for the main controller
+const MODULE_REQUIRES = ["folder-display-helpers",
+                         "window-helpers",
+                         "dom-helpers"];
 
 var elib = {};
 Cu.import('resource://mozmill/modules/elementslib.js', elib);
@@ -13,14 +17,6 @@ Cu.import('resource://mozmill/modules/mozmill.js', mozmill);
 var utils = {};
 Cu.import('resource://mozmill/modules/utils.js', utils);
 
-const MODULE_NAME = 'compose-helpers';
-
-const RELATIVE_ROOT = '../shared-modules';
-
-// we need this for the main controller
-const MODULE_REQUIRES = ['folder-display-helpers',
-                         'window-helpers',
-                         'dom-helpers'];
 const kTextNodeType = 3;
 
 var folderDisplayHelper;
@@ -40,6 +36,7 @@ function installInto(module) {
   // Now copy helper functions
   module.open_compose_new_mail = open_compose_new_mail;
   module.open_compose_with_reply = open_compose_with_reply;
+  module.open_compose_with_reply_to_all = open_compose_with_reply_to_all;
   module.open_compose_with_reply_to_list = open_compose_with_reply_to_list;
   module.open_compose_with_forward = open_compose_with_forward;
   module.open_compose_with_forward_as_attachments = open_compose_with_forward_as_attachments;
@@ -53,10 +50,6 @@ function installInto(module) {
   module.get_compose_body = get_compose_body;
   module.type_in_composer = type_in_composer;
   module.assert_previous_text = assert_previous_text;
-  module.assert_notification_displayed = assert_notification_displayed;
-  module.close_notification = close_notification;
-  module.wait_for_notification_to_stop = wait_for_notification_to_stop;
-  module.wait_for_notification_to_show = wait_for_notification_to_show;
 }
 
 /**
@@ -96,6 +89,23 @@ function open_compose_with_reply(aController) {
   return wait_for_compose_window();
 }
 
+/**
+ * Opens the compose window by replying to all for a selected message and waits
+ * for it to load.
+ *
+ * @return The loaded window of type "msgcompose" wrapped in a MozmillController
+ *         that is augmented using augment_controller.
+ */
+function open_compose_with_reply_to_all(aController) {
+  if (aController === undefined)
+    aController = mc;
+
+  windowHelper.plan_for_new_window("msgcompose");
+  aController.keypress(null, "R", {shiftKey: true, accelKey: true});
+
+  return wait_for_compose_window();
+}
+
 /**
  * Opens the compose window by replying to list for a selected message and waits for it
  * to load.
@@ -168,16 +178,31 @@ function open_compose_with_element_click(aElement, aController) {
 }
 
 /**
- * Closes the requested compose window. This function currently just forwards to
- * windowHelper but means we don't have to include windowHelper elsewhere if we
- * don't want it.
- *
- * In future it could also be expanded to handle prompting on close.
+ * Closes the requested compose window.
  *
  * @param aController the controller whose window is to be closed.
+ * @param aShouldPrompt (optional) true: check that the prompt to save appears
+ *                                 false: check there's no prompt to save
  */
-function close_compose_window(aController) {
-  windowHelper.close_window(aController);
+function close_compose_window(aController, aShouldPrompt) {
+  if (aShouldPrompt === undefined) { // caller doesn't care if we get a prompt
+    windowHelper.close_window(aController);
+    return;
+  }
+
+  windowHelper.plan_for_window_close(aController);
+  if (aShouldPrompt) {
+    windowHelper.plan_for_modal_dialog("commonDialog", function clickDontSave(controller) {
+       controller.window.document.documentElement.getButton("extra1").doCommand();
+    });
+    // Try to close, we should get a prompt to save.
+    aController.window.goDoCommand("cmd_close");
+    windowHelper.wait_for_modal_dialog();
+  }
+  else {
+    aController.window.goDoCommand("cmd_close");
+  }
+  windowHelper.wait_for_window_close();
 }
 
 /**
@@ -194,7 +219,7 @@ function wait_for_compose_window(aController) {
 
   let replyWindow = windowHelper.wait_for_new_window("msgcompose");
 
-  let editor = replyWindow.window.document.getElementsByTagName("editor")[0];
+  let editor = replyWindow.window.document.querySelector("editor");
 
   if (editor.webNavigation.busyFlags != Ci.nsIDocShell.BUSY_FLAGS_NONE) {
     let editorObserver = {
@@ -282,86 +307,6 @@ function delete_attachment(aComposeWindow, aIndex) {
   aComposeWindow.window.RemoveSelectedAttachment();
 }
 
-/**
- * A helper function for determining whether or not a notification with
- * a particular value is being displayed in the composer window.
- *
- * @param aController the controller of the compose window to check
- * @param aValue the value of the notification to look for.
- * @param aDisplayed true if the notification should be displayed, false
- *                   otherwise.
- * @returns the notification if we're asserting that the notification is
- *          displayed, and it actually shows up. Returns null otherwise.
- */
-function assert_notification_displayed(aController, aValue, aDisplayed) {
-  let nb = aController.window
-                      .document
-                      .getElementById("attachmentNotificationBox");
-  let hasNotification = false;
-  let notification = nb.getNotificationWithValue(aValue);
-  let hasNotification = (notification != null)
-
-  if (hasNotification != aDisplayed)
-    throw new Error("Expected the notification with value " + aValue +
-                    " to be " + (aDisplayed ? "shown" : "not shown"));
-
-  return notification;
-}
-
-/**
- * A helper function for closing a notification in the compose window if
- * one is currently displayed.
- *
- * @param aController the controller for the compose window with
- *                    the notification.
- * @param aValue the value of the notification to close.
- */
-function close_notification(aController, aValue) {
-  let nb = aController.window
-                      .document
-                      .getElementById("attachmentNotificationBox");
-  let notification = nb.getNotificationWithValue(aValue);
-
-  if (notification)
-    notification.close();
-}
-
-/**
- * A helper function that waits for a notification with value aValue
- * to stop displaying in the compose window.
- *
- * @param aController the controller for the compose window with the
- *                    notification.
- * @param aValue the value of the notification to wait to stop.
- */
-function wait_for_notification_to_stop(aController, aValue) {
-  let nb = aController.window
-                      .document
-                      .getElementById("attachmentNotificationBox");
-
-  aController.waitFor(function() !nb.getNotificationWithValue(aValue),
-                      "Timed out waiting for notification with value " +
-                      aValue + " to stop.");
-}
-
-/**
- * A helper function that waits for a notification with value aValue
- * to show in the compose window.
- *
- * @param aController the controller for the compose window that we want
- *                    the notification to appear in.
- * @param aValue the value of the notification to wait for.
- */
-function wait_for_notification_to_show(aController, aValue) {
-  let nb = aController.window
-                      .document
-                      .getElementById("attachmentNotificationBox");
-
-  aController.waitFor(function() nb.getNotificationWithValue(aValue) != null,
-                      "Timed out waiting for notification with value " +
-                      aValue + " to show.");
-}
-
 /**
  * Helper function returns the message body element of a composer window.
  *
