@@ -27,7 +27,7 @@ using namespace mozilla;
 class nsAbQueryLDAPMessageListener : public nsAbLDAPListenerBase
 {
 public:
-  NS_DECL_ISUPPORTS
+  NS_DECL_THREADSAFE_ISUPPORTS
 
   // Note that the directoryUrl is the details of the ldap directory
   // without any search params or return attributes specified. The searchUrl
@@ -74,7 +74,7 @@ protected:
 };
 
 
-NS_IMPL_THREADSAFE_ISUPPORTS1(nsAbQueryLDAPMessageListener, nsILDAPMessageListener)
+NS_IMPL_ISUPPORTS1(nsAbQueryLDAPMessageListener, nsILDAPMessageListener)
 
 nsAbQueryLDAPMessageListener::nsAbQueryLDAPMessageListener(
         nsIAbDirectoryQueryResultListener *resultListener,
@@ -291,7 +291,7 @@ nsresult nsAbQueryLDAPMessageListener::OnLDAPMessageSearchResult(nsILDAPMessage
 
 // nsAbLDAPDirectoryQuery
 
-NS_IMPL_THREADSAFE_ISUPPORTS2(nsAbLDAPDirectoryQuery, nsIAbDirectoryQuery,
+NS_IMPL_ISUPPORTS2(nsAbLDAPDirectoryQuery, nsIAbDirectoryQuery,
                               nsIAbDirectoryQueryResultListener)
 
 nsAbLDAPDirectoryQuery::nsAbLDAPDirectoryQuery() :
@@ -420,18 +420,25 @@ NS_IMETHODIMP nsAbLDAPDirectoryQuery::DoQuery(nsIAbDirectory *aDirectory,
   // nsAbLDAPCard::SetMetaProperties
   rv = url->AddAttribute(NS_LITERAL_CSTRING("objectClass"));
 
-  // Get the filter
-  nsCOMPtr<nsISupports> supportsExpression;
-  rv = aArguments->GetExpression (getter_AddRefs (supportsExpression));
-  NS_ENSURE_SUCCESS(rv, rv);
-  
-  nsCOMPtr<nsIAbBooleanExpression> expression (do_QueryInterface (supportsExpression, &rv));
   nsAutoCString filter;
-  
-  // figure out how we map attribute names to addressbook fields for this
-  // query
-  rv = nsAbBoolExprToLDAPFilter::Convert(map, expression, filter);
+
+  // Get filter from arguments if set:
+  rv = aArguments->GetFilter(filter);
   NS_ENSURE_SUCCESS(rv, rv);
+  
+  if (filter.IsEmpty()) {
+    // Get the filter
+    nsCOMPtr<nsISupports> supportsExpression;
+    rv = aArguments->GetExpression(getter_AddRefs(supportsExpression));
+    NS_ENSURE_SUCCESS(rv, rv);
+
+    nsCOMPtr<nsIAbBooleanExpression> expression(do_QueryInterface(supportsExpression, &rv));
+
+    // figure out how we map attribute names to addressbook fields for this
+    // query
+    rv = nsAbBoolExprToLDAPFilter::Convert(map, expression, filter);
+    NS_ENSURE_SUCCESS(rv, rv);
+  }
 
   /*
    * Mozilla itself cannot arrive here with a blank filter
