@@ -1,41 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
-* Version: MPL 1.1/GPL 2.0/LGPL 2.1
-*
-* The contents of this file are subject to the Mozilla Public License Version
-* 1.1 (the "License"); you may not use this file except in compliance with
-* the License. You may obtain a copy of the License at
-* http://www.mozilla.org/MPL/
-*
-* Software distributed under the License is distributed on an "AS IS" basis,
-* WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-* for the specific language governing rights and limitations under the
-* License.
-*
-* The Original Code is mozilla.org code.
-*
-* The Initial Developer of the Original Code is
-* Peter Van der Beken.
-* Portions created by the Initial Developer are Copyright (C) 2004
-* the Initial Developer. All Rights Reserved.
-*
-* Contributor(s):
-*   Peter Van der Beken <peterv@propagandism.org>
-*
-*
-* Alternatively, the contents of this file may be used under the terms of
-* either the GNU General Public License Version 2 or later (the "GPL"), or
-* the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
-* in which case the provisions of the GPL or the LGPL are applicable instead
-* of those above. If you wish to allow use of your version of this file only
-* under the terms of either the GPL or the LGPL, and not to allow others to
-* use your version of this file under the terms of the MPL, indicate your
-* decision by deleting the provisions above and replace them with the notice
-* and other provisions required by the GPL or the LGPL. If you do not delete
-* the provisions above, a recipient may use your version of this file under
-* the terms of any one of the MPL, the GPL or the LGPL.
-*
-* ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+* License, v. 2.0. If a copy of the MPL was not distributed with this
+* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "nsAbOSXDirectory.h"
 #include "nsAbOSXCard.h"
@@ -55,27 +21,17 @@
 #include "nsISimpleEnumerator.h"
 
 #include <AddressBook/AddressBook.h>
-#if (MAC_OS_X_VERSION_MAX_ALLOWED < MAC_OS_X_VERSION_10_3)
-#define kABDeletedRecords @"ABDeletedRecords"
-#define kABUpdatedRecords @"ABUpdatedRecords"
-#define kABInsertedRecords @"ABInsertedRecords"
-#elif (MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_3)
+
 #define kABDeletedRecords (kABDeletedRecords? kABDeletedRecords : @"ABDeletedRecords")
 #define kABUpdatedRecords (kABUpdatedRecords ? kABUpdatedRecords : @"ABUpdatedRecords")
 #define kABInsertedRecords (kABInsertedRecords ? kABInsertedRecords : @"ABInsertedRecords")
-#endif
-
-/* Each nsAbOSXDirectory contains a lookup table for their respective
- * nsAbOSXCard's.  We set the initial size of that lookup table here.
- */
-#define OSX_CARD_STORE_INIT 100
 
 static nsresult
 GetOrCreateGroup(NSString *aUid, nsIAbDirectory **aResult)
 {
   NS_ASSERTION(aUid, "No UID for group!.");
 
-  nsCAutoString uri(NS_ABOSXDIRECTORY_URI_PREFIX);
+  nsAutoCString uri(NS_ABOSXDIRECTORY_URI_PREFIX);
   AppendToCString(aUid, uri);
 
   nsresult rv;
@@ -98,7 +54,7 @@ GetCard(ABRecord *aRecord, nsIAbCard **aResult, nsIAbOSXDirectory *osxDirectory)
   if (!uid)
     return NS_ERROR_FAILURE;
 
-  nsCAutoString uri(NS_ABOSXCARD_URI_PREFIX);
+  nsAutoCString uri(NS_ABOSXCARD_URI_PREFIX);
   AppendToCString(uid, uri);
   nsCOMPtr<nsIAbOSXCard> osxCard;
   nsresult rv = osxDirectory->GetCardByUri(uri, getter_AddRefs(osxCard));
@@ -123,7 +79,7 @@ CreateCard(ABRecord *aRecord, nsIAbCard **aResult)
   nsCOMPtr<nsIAbOSXCard> osxCard = do_CreateInstance(NS_ABOSXCARD_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCAutoString uri(NS_ABOSXCARD_URI_PREFIX);
+  nsAutoCString uri(NS_ABOSXCARD_URI_PREFIX);
   AppendToCString(uid, uri);
 
   rv = osxCard->Init(uri.get());
@@ -148,7 +104,9 @@ Sync(NSString *aUid)
     nsCOMPtr<nsIAbOSXDirectory> osxDirectory =
       do_QueryInterface(directory);
     
-    osxDirectory->Update();
+    if (osxDirectory) {
+      osxDirectory->Update();
+    }
   }
   else {
     nsCOMPtr<nsIAbCard> abCard;
@@ -189,16 +147,16 @@ Sync(NSString *aUid)
 
   if (inserted) {
     nsCOMPtr<nsIAbManager> abManager = do_GetService(NS_ABMANAGER_CONTRACTID, &rv);
-    NS_ENSURE_SUCCESS(rv, );
+    NS_ENSURE_SUCCESS_VOID(rv);
 
     nsCOMPtr<nsIAbDirectory> directory;
     rv = abManager->GetDirectory(NS_LITERAL_CSTRING(NS_ABOSXDIRECTORY_URI_PREFIX"/"),
                                  getter_AddRefs(directory));
-    NS_ENSURE_SUCCESS(rv, );
+    NS_ENSURE_SUCCESS_VOID(rv);
 
     nsCOMPtr<nsIAbOSXDirectory> osxDirectory =
       do_QueryInterface(directory, &rv);
-    NS_ENSURE_SUCCESS(rv, );
+    NS_ENSURE_SUCCESS_VOID(rv);
 
     unsigned int i, count = [inserted count];
     for (i = 0; i < count; ++i) {
@@ -210,17 +168,17 @@ Sync(NSString *aUid)
         nsCOMPtr<nsIAbDirectory> directory;
         GetOrCreateGroup([inserted objectAtIndex:i],
                          getter_AddRefs(directory));
-        
+
         rv = osxDirectory->AssertDirectory(abManager, directory);
-        NS_ENSURE_SUCCESS(rv, );
+        NS_ENSURE_SUCCESS_VOID(rv);
       }
       else {
         nsCOMPtr<nsIAbCard> abCard;
         // Construct a card
         nsresult rv = CreateCard(card, getter_AddRefs(abCard));
-        NS_ENSURE_SUCCESS(rv, );
+        NS_ENSURE_SUCCESS_VOID(rv);
         rv = osxDirectory->AssertCard(abManager, abCard);
-        NS_ENSURE_SUCCESS(rv, );
+        NS_ENSURE_SUCCESS_VOID(rv);
       }
     }
   }
@@ -238,26 +196,26 @@ Sync(NSString *aUid)
   if (deleted) {
 
     nsCOMPtr<nsIAbManager> abManager = do_GetService(NS_ABMANAGER_CONTRACTID, &rv);
-    NS_ENSURE_SUCCESS(rv, );
+    NS_ENSURE_SUCCESS_VOID(rv);
 
     nsCOMPtr<nsIAbDirectory> directory;
     rv = abManager->GetDirectory(NS_LITERAL_CSTRING(NS_ABOSXDIRECTORY_URI_PREFIX"/"),
                                  getter_AddRefs(directory));
-    NS_ENSURE_SUCCESS(rv, );
+    NS_ENSURE_SUCCESS_VOID(rv);
 
     nsCOMPtr<nsIAbOSXDirectory> osxDirectory =
       do_QueryInterface(directory, &rv);
-    NS_ENSURE_SUCCESS(rv, );
+    NS_ENSURE_SUCCESS_VOID(rv);
 
     unsigned int i, count = [deleted count];
     for (i = 0; i < count; ++i) {
       NSString *deletedUid = [deleted objectAtIndex:i];
 
-      nsCAutoString uid;
+      nsAutoCString uid;
       AppendToCString(deletedUid, uid);
 
       rv = osxDirectory->DeleteUid(uid);
-      NS_ENSURE_SUCCESS(rv, );
+      NS_ENSURE_SUCCESS_VOID(rv);
     }
   }
   
@@ -346,16 +304,16 @@ MapConditionString(nsIAbBooleanConditionString *aCondition, bool aNegate,
   rv = aCondition->GetValue(getter_Copies(value));
   NS_ENSURE_SUCCESS(rv, rv);
   
-  PRUint32 length = value.Length();
+  uint32_t length = value.Length();
   
-  PRUint32 i;
+  uint32_t i;
   for (i = 0; i < nsAbOSXUtils::kPropertyMapSize; ++i) {
     if (name.Equals(nsAbOSXUtils::kPropertyMap[i].mPropertyName)) {
       *aResult =
       [ABPerson searchElementForProperty:nsAbOSXUtils::kPropertyMap[i].mOSXProperty
                                    label:nsAbOSXUtils::kPropertyMap[i].mOSXLabel
                                      key:nsAbOSXUtils::kPropertyMap[i].mOSXKey
-                                   value:[NSString stringWithCharacters:value.get() length:length]
+                                   value:[NSString stringWithCharacters:reinterpret_cast<const unichar*>(value.get()) length:length]
                               comparison:comparison];
       
       return NS_OK;
@@ -367,19 +325,19 @@ MapConditionString(nsIAbBooleanConditionString *aCondition, bool aNegate,
     [ABPerson searchElementForProperty:kABFirstNameProperty
                                  label:nil
                                    key:nil
-                                 value:[NSString stringWithCharacters:value.get() length:length]
+                                 value:[NSString stringWithCharacters:reinterpret_cast<const unichar*>(value.get()) length:length]
                             comparison:comparison];
     ABSearchElement *second =
       [ABPerson searchElementForProperty:kABLastNameProperty
                                    label:nil
                                      key:nil
-                                   value:[NSString stringWithCharacters:value.get() length:length]
+                                   value:[NSString stringWithCharacters:reinterpret_cast<const unichar*>(value.get()) length:length]
                               comparison:comparison];
     ABSearchElement *third =
       [ABGroup searchElementForProperty:kABGroupNameProperty
                                   label:nil
                                     key:nil
-                                  value:[NSString stringWithCharacters:value.get() length:length]
+                                  value:[NSString stringWithCharacters:reinterpret_cast<const unichar*>(value.get()) length:length]
                              comparison:comparison];
     
     *aResult = [ABSearchElement searchElementForConjunction:kABSearchOr children:[NSArray arrayWithObjects:first, second, third, nil]];
@@ -407,22 +365,22 @@ BuildSearchElements(nsIAbBooleanExpression *aExpression,
   rv = aExpression->GetOperation(&operation);
   NS_ENSURE_SUCCESS(rv, rv);
   
-  PRUint32 count;
+  uint32_t count;
   rv = expressions->GetLength(&count);
   NS_ENSURE_SUCCESS(rv, rv);
   
   NS_ASSERTION(count > 1 && operation != nsIAbBooleanOperationTypes::NOT,
                "This doesn't make sense!");
   
-  NSMutableArray *array = nsnull;
+  NSMutableArray *array = nullptr;
   if (count > 1)
     array = [[NSMutableArray alloc] init];
   
-  PRUint32 i;
+  uint32_t i;
   nsCOMPtr<nsIAbBooleanConditionString> condition;
   nsCOMPtr<nsIAbBooleanExpression> subExpression;
   for (i = 0; i < count; ++i) {
-    ABSearchElement *element = nsnull;
+    ABSearchElement *element = nullptr;
     
     condition = do_QueryElementAt(expressions, i);
     if (condition) {
@@ -478,12 +436,11 @@ Search(nsIAbBooleanExpression *aExpression, NSArray **aResult)
   return canHandle;
 }
 
-static PRUint32 sObserverCount = 0;
-static ABChangedMonitor *sObserver = nsnull;
+static uint32_t sObserverCount = 0;
+static ABChangedMonitor *sObserver = nullptr;
 
 nsAbOSXDirectory::nsAbOSXDirectory()
 {
-  mCardStore.Init(OSX_CARD_STORE_INIT);
 }
 
 nsAbOSXDirectory::~nsAbOSXDirectory()
@@ -538,14 +495,14 @@ nsAbOSXDirectory::Init(const char *aUri)
   }
   else
   {
-    nsCAutoString uid(Substring(mURINoQuery, sizeof(NS_ABOSXDIRECTORY_URI_PREFIX) - 1));
+    nsAutoCString uid(Substring(mURINoQuery, sizeof(NS_ABOSXDIRECTORY_URI_PREFIX) - 1));
     ABRecord *card = [addressBook recordForUniqueId:[NSString stringWithUTF8String:uid.get()]];
     NS_ASSERTION([card isKindOfClass:[ABGroup class]], "Huh.");
 
     m_IsMailList = true;
     AppendToString([card valueForProperty:kABGroupNameProperty], m_ListDirName);
 
-    ABGroup *group = (ABGroup*)[addressBook recordForUniqueId:[NSString stringWithUTF8String:nsCAutoString(Substring(mURINoQuery, 21)).get()]];
+    ABGroup *group = (ABGroup*)[addressBook recordForUniqueId:[NSString stringWithUTF8String:nsAutoCString(Substring(mURINoQuery, 21)).get()]];
     cards = [[group members] arrayByAddingObjectsFromArray:[group subgroups]];
 
     if (!m_AddressList)
@@ -558,7 +515,7 @@ nsAbOSXDirectory::Init(const char *aUri)
   }
 
 
-  nsCAutoString ourUuid;
+  nsAutoCString ourUuid;
   GetUuid(ourUuid);
 
   unsigned int nbCards = [cards count];
@@ -627,7 +584,7 @@ CheckRedundantCards(nsIAbManager *aManager, nsIAbDirectory *aDirectory,
   nsCOMPtr<nsIAbOSXCard> osxCard = do_QueryInterface(aCard, &rv);
   NS_ENSURE_SUCCESS(rv, false);
 
-  nsCAutoString uri;
+  nsAutoCString uri;
   rv = osxCard->GetURI(uri);
   NS_ENSURE_SUCCESS(rv, false);
   NSString *uid = [NSString stringWithUTF8String:(uri.get() + 21)];
@@ -691,7 +648,7 @@ nsAbOSXDirectory::Update()
   nsIMutableArray* cardList;
   NSArray *groups, *cards;
   if (m_IsMailList) {
-    ABGroup *group = (ABGroup*)[addressBook recordForUniqueId:[NSString stringWithUTF8String:nsCAutoString(Substring(mURINoQuery, 21)).get()]];
+    ABGroup *group = (ABGroup*)[addressBook recordForUniqueId:[NSString stringWithUTF8String:nsAutoCString(Substring(mURINoQuery, 21)).get()]];
     groups = nil;
     cards = [[group members] arrayByAddingObjectsFromArray:[group subgroups]];
 
@@ -717,7 +674,7 @@ nsAbOSXDirectory::Update()
   }
   
   NSMutableArray *mutableArray = [NSMutableArray arrayWithArray:cards];
-  PRUint32 addressCount;
+  uint32_t addressCount;
   rv = cardList->GetLength(&addressCount);
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -747,7 +704,7 @@ nsAbOSXDirectory::Update()
     AssertCard(abManager, abCard);
   }
   
-  card = (ABRecord*)[addressBook recordForUniqueId:[NSString stringWithUTF8String:nsCAutoString(Substring(mURINoQuery, 21)).get()]];
+  card = (ABRecord*)[addressBook recordForUniqueId:[NSString stringWithUTF8String:nsAutoCString(Substring(mURINoQuery, 21)).get()]];
   NSString * stringValue = [card valueForProperty:kABGroupNameProperty];
   if (![stringValue isEqualToString:WrapString(m_ListDirName)])
   {
@@ -776,7 +733,7 @@ nsAbOSXDirectory::Update()
         if (NS_FAILED(rv))
           continue;
 
-        nsCAutoString uri;
+        nsAutoCString uri;
         directory->GetURI(uri);
         uri.Cut(0, 21);
         NSString *uid = [NSString stringWithUTF8String:uri.get()];
@@ -846,7 +803,7 @@ nsresult
 nsAbOSXDirectory::AssertDirectory(nsIAbManager *aManager,
                                   nsIAbDirectory *aDirectory)
 {
-  PRUint32 pos;
+  uint32_t pos;
   if (m_AddressList &&
       NS_SUCCEEDED(m_AddressList->IndexOf(0, aDirectory, &pos)))
     // We already have this directory, so no point in adding it again.
@@ -868,7 +825,7 @@ nsresult
 nsAbOSXDirectory::AssertCard(nsIAbManager *aManager,
                              nsIAbCard *aCard)
 {
-  nsCAutoString ourUuid;
+  nsAutoCString ourUuid;
   GetUuid(ourUuid);
   aCard->SetDirectoryId(ourUuid);
 
@@ -896,7 +853,7 @@ nsAbOSXDirectory::UnassertCard(nsIAbManager *aManager,
                                nsIMutableArray *aCardList)
 {
   nsresult rv;
-  PRUint32 pos;
+  uint32_t pos;
   
   if (NS_SUCCEEDED(aCardList->IndexOf(0, aCard, &pos)))
     rv = aCardList->RemoveElementAt(pos);
@@ -910,7 +867,7 @@ nsAbOSXDirectory::UnassertDirectory(nsIAbManager *aManager,
 {
   NS_ENSURE_TRUE(m_AddressList, NS_ERROR_NULL_POINTER);
 
-  PRUint32 pos;
+  uint32_t pos;
   if (NS_SUCCEEDED(m_AddressList->IndexOf(0, aDirectory, &pos)))
   {
     nsresult rv = m_AddressList->RemoveElementAt(pos);
@@ -957,7 +914,7 @@ nsAbOSXDirectory::GetChildCards(nsISimpleEnumerator **aCards)
     NS_ENSURE_SUCCESS(rv, rv);
   
     // The uuid for initializing cards
-    nsCAutoString ourUuid;
+    nsAutoCString ourUuid;
     GetUuid(ourUuid);
 
     // Fill the results array and update the card list
@@ -1049,7 +1006,7 @@ nsAbOSXDirectory::GetCardFromProperty(const char *aProperty,
 {
   NS_ENSURE_ARG_POINTER(aResult);
 
-  *aResult = nsnull;
+  *aResult = nullptr;
 
   if (aValue.IsEmpty())
     return NS_OK;
@@ -1059,14 +1016,14 @@ nsAbOSXDirectory::GetCardFromProperty(const char *aProperty,
   if (!list)
     return NS_OK;
 
-  PRUint32 length;
+  uint32_t length;
   nsresult rv = list->GetLength(&length);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIAbCard> card;
-  nsCAutoString cardValue;
+  nsAutoCString cardValue;
 
-  for (PRUint32 i = 0; i < length && !*aResult; ++i)
+  for (uint32_t i = 0; i < length && !*aResult; ++i)
   {
     card = do_QueryElementAt(list, i, &rv);
     if (NS_SUCCEEDED(rv))
@@ -1097,7 +1054,7 @@ nsAbOSXDirectory::GetCardsFromProperty(const char *aProperty,
 {
   NS_ENSURE_ARG_POINTER(aResult);
 
-  *aResult = nsnull;
+  *aResult = nullptr;
 
   if (aValue.IsEmpty())
     return NS_NewEmptyEnumerator(aResult);
@@ -1107,15 +1064,15 @@ nsAbOSXDirectory::GetCardsFromProperty(const char *aProperty,
   if (!list)
     return NS_NewEmptyEnumerator(aResult);
 
-  PRUint32 length;
+  uint32_t length;
   nsresult rv = list->GetLength(&length);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMArray<nsIAbCard> resultArray;
   nsCOMPtr<nsIAbCard> card;
-  nsCAutoString cardValue;
+  nsAutoCString cardValue;
 
-  for (PRUint32 i = 0; i < length; ++i)
+  for (uint32_t i = 0; i < length; ++i)
   {
     card = do_QueryElementAt(list, i, &rv);
     if (NS_SUCCEEDED(rv))
@@ -1145,7 +1102,7 @@ nsAbOSXDirectory::CardForEmailAddress(const nsACString &aEmailAddress,
 {
   NS_ENSURE_ARG_POINTER(aResult);
 
-  *aResult = nsnull;
+  *aResult = nullptr;
 
   if (aEmailAddress.IsEmpty())
     return NS_OK;
@@ -1155,13 +1112,13 @@ nsAbOSXDirectory::CardForEmailAddress(const nsACString &aEmailAddress,
   if (!list)
     return NS_OK;
 
-  PRUint32 length;
+  uint32_t length;
   nsresult rv = list->GetLength(&length);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIAbCard> card;
 
-  for (PRUint32 i = 0; i < length && !*aResult; ++i)
+  for (uint32_t i = 0; i < length && !*aResult; ++i)
   {
     card = do_QueryElementAt(list, i, &rv);
     if (NS_SUCCEEDED(rv))
@@ -1183,7 +1140,7 @@ nsAbOSXDirectory::HasCard(nsIAbCard *aCard, bool *aHasCard)
   NS_ENSURE_ARG_POINTER(aHasCard);
 
   nsresult rv = NS_OK;
-  PRUint32 index;
+  uint32_t index;
   if (m_IsMailList)
   {
     if (m_AddressList)
@@ -1206,7 +1163,7 @@ nsAbOSXDirectory::HasDirectory(nsIAbDirectory *aDirectory,
   
   *aHasDirectory = false;
 
-  PRUint32 pos;
+  uint32_t pos;
   if (m_AddressList && NS_SUCCEEDED(m_AddressList->IndexOf(0, aDirectory, &pos)))
     *aHasDirectory = true;
 
@@ -1214,7 +1171,7 @@ nsAbOSXDirectory::HasDirectory(nsIAbDirectory *aDirectory,
 }
 
 NS_IMETHODIMP
-nsAbOSXDirectory::OnSearchFinished(PRInt32 aResult, const nsAString &aErrorMsg)
+nsAbOSXDirectory::OnSearchFinished(int32_t aResult, const nsAString &aErrorMsg)
 {
   return NS_OK;
 }
@@ -1239,7 +1196,7 @@ nsAbOSXDirectory::OnSearchFoundCard(nsIAbCard *aCard)
   rv = mCardList->AppendElement(aCard, false);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCAutoString ourUuid;
+  nsAutoCString ourUuid;
   GetUuid(ourUuid);
   aCard->SetDirectoryId(ourUuid);
   
@@ -1297,7 +1254,7 @@ nsAbOSXDirectory::FallbackSearch(nsIAbBooleanExpression *aExpression,
   rv = queryProxy->Initiate();
   NS_ENSURE_SUCCESS(rv, rv);
   
-  PRInt32 context = 0;
+  int32_t context = 0;
   rv = queryProxy->DoQuery(directory, arguments, this, -1, 0, &context);
   NS_ENSURE_SUCCESS(rv, rv);
   
@@ -1321,11 +1278,11 @@ nsresult nsAbOSXDirectory::DeleteUid(const nsACString &aUid)
   // First, we'll see if its in the group list as it is likely to be shorter.
 
   // See if this item is in our address list
-  PRUint32 addressCount;
+  uint32_t addressCount;
   rv = m_AddressList->GetLength(&addressCount);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCAutoString uri(NS_ABOSXDIRECTORY_URI_PREFIX);
+  nsAutoCString uri(NS_ABOSXDIRECTORY_URI_PREFIX);
   uri.Append(aUid);
 
   // Iterate backwards in case we remove something
@@ -1339,7 +1296,7 @@ nsresult nsAbOSXDirectory::DeleteUid(const nsACString &aUid)
     nsCOMPtr<nsIAbDirectory> directory(do_QueryInterface(abItem, &rv));
     if (NS_SUCCEEDED(rv))
     {
-      nsCAutoString dirUri;
+      nsAutoCString dirUri;
       directory->GetURI(dirUri);
       if (uri.Equals(dirUri))
         return UnassertDirectory(abManager, directory);
@@ -1347,7 +1304,7 @@ nsresult nsAbOSXDirectory::DeleteUid(const nsACString &aUid)
       nsCOMPtr<nsIAbOSXCard> osxCard(do_QueryInterface(abItem, &rv));
       if (NS_SUCCEEDED(rv))
       {
-        nsCAutoString cardUri;
+        nsAutoCString cardUri;
         osxCard->GetURI(cardUri);
         if (uri.Equals(cardUri))
         {
@@ -1375,7 +1332,7 @@ nsresult nsAbOSXDirectory::DeleteUid(const nsACString &aUid)
     if (NS_FAILED(rv))
       continue;
 
-    nsCAutoString cardUri;
+    nsAutoCString cardUri;
     osxCard->GetURI(cardUri);
 
     if (uri.Equals(cardUri)) {
