@@ -243,6 +243,9 @@ function onAccept(aDoChecks) {
     // Check if user/host have been modified correctly.
     if (!checkUserServerChanges(true))
       return false;
+
+    if (!checkAccountNameIsValid())
+      return false;
   }
 
   if (!onSave())
@@ -380,11 +383,7 @@ function checkDirectoryIsAllowed(aLocalPath) {
   // allow that directory.
   if (currentAccount.incomingServer) {
     try {
-      let defaultPath = Components
-        .classes["@mozilla.org/messenger/protocol/info;1?type=" +
-                 currentAccount.incomingServer.type]
-        .getService(Components.interfaces.nsIMsgProtocolInfo)
-        .defaultLocalPath;
+      let defaultPath = currentAccount.incomingServer.protocolInfo.defaultLocalPath;
       if (defaultPath) {
         defaultPath.normalize();
         if (defaultPath.contains(aLocalPath, true))
@@ -491,6 +490,8 @@ function checkUserServerChanges(showAlert) {
   if (!pageElements)
     return true;
 
+  let currentServer = currentAccount ? currentAccount.incomingServer : null;
+
   // Get the new username, hostname and type from the page
   var newUser, newHost, newType, oldUser, oldHost;
   var uIndx, hIndx;
@@ -521,8 +522,8 @@ function checkUserServerChanges(showAlert) {
   }
 
   var checkUser = true;
-  // There is no username defined for news so reset it.
-  if (newType == "nntp") {
+  // There is no username needed for e.g. news so reset it.
+  if (currentServer && !currentServer.protocolInfo.requiresUsername) {
     oldUser = newUser = "";
     checkUser = false;
   }
@@ -540,7 +541,7 @@ function checkUserServerChanges(showAlert) {
     else {
       let sameServer = MailServices.accounts
                                    .findRealServer(newUser, newHost, newType, 0);
-      if (sameServer && (sameServer != currentAccount.incomingServer)) {
+      if (sameServer && (sameServer != currentServer)) {
         alertText = prefBundle.getString("modifiedAccountExists");
       } else {
         // New hostname passed all checks. We may have cleaned it up so set
@@ -566,8 +567,8 @@ function checkUserServerChanges(showAlert) {
     // to edit rules.
     if (showAlert) {
       let filterList;
-      if (currentAccount && checkUser) {
-        filterList = currentAccount.incomingServer.getEditableFilterList(null);
+      if (currentServer && checkUser) {
+        filterList = currentServer.getEditableFilterList(null);
       }
       let changeText = "";
       if ((oldHost != newHost) &&
@@ -587,8 +588,12 @@ function checkUserServerChanges(showAlert) {
   for (let i = 0; i < pageElements.length; i++) {
     if (pageElements[i].id) {
       if (pageElements[i].id == "server.localPath") {
-        if (!checkDirectoryIsUsable(getFormElementValue(pageElements[i])))
-          return false;
+        if (!checkDirectoryIsUsable(getFormElementValue(pageElements[i]))) {
+//          return false; // Temporarily disable this. Just show warning but do not block. See bug 921371.
+          Components.utils.reportError("Local directory '" +
+            getFormElementValue(pageElements[i]).path + "' of account " +
+            currentAccount.key + " is not safe to use. Consider changing it.");
+        }
         break;
       }
     }
@@ -627,6 +632,40 @@ function checkUserServerChanges(showAlert) {
   return true;
 }
 
+/**
+ * If account name is not valid, alert the user.
+ */
+function checkAccountNameIsValid() {
+  if (!currentAccount)
+    return true;
+
+  let pageElements = getPageFormElements();
+  if (!pageElements)
+    return true;
+
+  const prefBundle = document.getElementById("bundle_prefs");
+  let alertText = null;
+
+  for (let i = 0; i < pageElements.length; i++) {
+    if (!pageElements[i].id || pageElements[i].id != "server.prettyName")
+      continue;
+
+    let accountName = getFormElementValue(pageElements[i]);
+    if (!accountName)
+      alertText = prefBundle.getString("accountNameEmpty");
+    else if (accountNameExists(accountName, currentAccount.key))
+      alertText = prefBundle.getString("accountNameExists");
+
+    if (alertText) {
+      const alertTitle = prefBundle.getString("accountWizard");
+      Services.prompt.alert(window, alertTitle, alertText);
+      return false;
+    }
+  }
+
+  return true;
+}
+
 function onSave() {
   if (pendingPageId) {
     dump("ERROR: " + pendingPageId + " hasn't loaded yet! Not saving.\n");
@@ -704,15 +743,9 @@ function onRemoveAccount(event) {
     return;
 
   let server = currentAccount.incomingServer;
-  let type = server.type;
   let prettyName = server.prettyName;
 
-  let canDelete = false;
-  if (Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + type]
-                .getService(Components.interfaces.nsIMsgProtocolInfo).canDelete)
-    canDelete = true;
-  else
-    canDelete = server.canDelete;
+  let canDelete = server.protocolInfo.canDelete || server.canDelete;
 
   if (!canDelete)
     return;
@@ -925,17 +958,12 @@ function updateItems(tree, account, addAccountItem, setDefaultItem, removeItem)
     // Otherwise we have either selected a SMTP server, or there is some
     // problem. Either way, we don't want the user to act on it.
     let server = account.incomingServer;
-    let type = server.type;
 
     if (account != MailServices.accounts.defaultAccount &&
         server.canBeDefaultServer && account.identities.length > 0)
       canSetDefault = true;
 
-    if (Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + type]
-                  .getService(Components.interfaces.nsIMsgProtocolInfo).canDelete)
-      canDelete = true;
-    else
-      canDelete = server.canDelete;
+    canDelete = server.protocolInfo.canDelete || server.canDelete;
   }
 
   setEnabled(addAccountItem, true);
@@ -1011,6 +1039,15 @@ function onAccountTreeSelect(pageId, account)
       onAccept(false);
   }
 
+  if (document.getElementById("contentFrame").contentDocument.getElementById("server.prettyName")) {
+    // Check if account name is valid.
+    if (!checkAccountNameIsValid()) {
+      changeView = true;
+      account = currentAccount;
+      pageId = currentPageId;
+    }
+  }
+
   if (currentPageId) {
     // Change focus to the account tree first so that any 'onchange' handlers
     // on elements in the current page have a chance to run before the page
@@ -1342,6 +1379,13 @@ function setFormElementValue(formElement, value) {
       formElement.value = value;
     }
   }
+  else if (type == "label") {
+    if (value == null || value == undefined) {
+      formElement.value = "";
+    } else {
+      formElement.value = value;
+    }
+  }
 
   // let the form figure out what to do with it
   else {
