@@ -126,23 +126,21 @@ NS_IMETHODIMP  nsMsgFilterService::SaveFilterList(nsIMsgFilterList *filterList,
   NS_ENSURE_ARG_POINTER(filterFile);
   NS_ENSURE_ARG_POINTER(filterList);
 
-  nsCOMPtr<nsIOutputStream> out;
-  nsresult rv = NS_NewSafeLocalFileOutputStream(getter_AddRefs(out),
-                                                filterFile, -1, 0600);
-  NS_ENSURE_SUCCESS(rv, rv);
-
   nsCOMPtr<nsIOutputStream> strm;
-  rv = NS_NewBufferedOutputStream(getter_AddRefs(strm), out, 4096);
+  nsresult rv = MsgNewSafeBufferedFileOutputStream(getter_AddRefs(strm),
+                                                filterFile, -1, 0600);
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = filterList->SaveToFile(strm);
 
   nsCOMPtr<nsISafeOutputStream> safeStream = do_QueryInterface(strm);
-  NS_ASSERTION(safeStream, "expected a safe output stream");
-  if (NS_SUCCEEDED(rv) && safeStream)
+  NS_ASSERTION(safeStream, "expected a safe output stream!");
+  if (safeStream) {
     rv = safeStream->Finish();
-
-  NS_ASSERTION(NS_SUCCEEDED(rv), "failed to save filter file");
+    if (NS_FAILED(rv)) {
+      NS_WARNING("failed to save filter file! possible data loss");
+    }
+  }
   return rv;
 }
 
@@ -246,7 +244,7 @@ nsMsgFilterService::ThrowAlertMsg(const char*aMsgName, nsIMsgWindow *aMsgWindow)
 class nsMsgFilterAfterTheFact : public nsIUrlListener, public nsIMsgSearchNotify, public nsIMsgCopyServiceListener
 {
 public:
-  nsMsgFilterAfterTheFact(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsISupportsArray *aFolderList);
+  nsMsgFilterAfterTheFact(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsIArray *aFolderList);
   virtual ~nsMsgFilterAfterTheFact();
   NS_DECL_ISUPPORTS
   NS_DECL_NSIURLLISTENER
@@ -260,32 +258,32 @@ protected:
   nsresult  OnEndExecution(nsresult executionStatus); // do what we have to do to cleanup.
   bool      ContinueExecutionPrompt();
   nsresult  DisplayConfirmationPrompt(nsIMsgWindow *msgWindow, const PRUnichar *confirmString, bool *confirmed);
-  nsCOMPtr <nsIMsgWindow>     m_msgWindow;
-  nsCOMPtr <nsIMsgFilterList> m_filters;
-  nsCOMPtr <nsISupportsArray> m_folders;
-  nsCOMPtr <nsIMsgFolder>     m_curFolder;
-  nsCOMPtr <nsIMsgDatabase>   m_curFolderDB;
-  nsCOMPtr <nsIMsgFilter>     m_curFilter;
+  nsCOMPtr<nsIMsgWindow>      m_msgWindow;
+  nsCOMPtr<nsIMsgFilterList>  m_filters;
+  nsCOMPtr<nsIArray>          m_folders;
+  nsCOMPtr<nsIMsgFolder>      m_curFolder;
+  nsCOMPtr<nsIMsgDatabase>    m_curFolderDB;
+  nsCOMPtr<nsIMsgFilter>      m_curFilter;
   uint32_t                    m_curFilterIndex;
   uint32_t                    m_curFolderIndex;
   uint32_t                    m_numFilters;
   uint32_t                    m_numFolders;
   nsTArray<nsMsgKey>          m_searchHits;
   nsCOMPtr<nsIMutableArray>   m_searchHitHdrs;
-  nsCOMPtr <nsIMsgSearchSession> m_searchSession;
+  nsCOMPtr<nsIMsgSearchSession> m_searchSession;
   uint32_t                    m_nextAction; // next filter action to perform
 };
 
 NS_IMPL_ISUPPORTS3(nsMsgFilterAfterTheFact, nsIUrlListener, nsIMsgSearchNotify, nsIMsgCopyServiceListener)
 
-nsMsgFilterAfterTheFact::nsMsgFilterAfterTheFact(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsISupportsArray *aFolderList)
+nsMsgFilterAfterTheFact::nsMsgFilterAfterTheFact(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsIArray *aFolderList)
 {
   m_curFilterIndex = m_curFolderIndex = m_nextAction = 0;
   m_msgWindow = aMsgWindow;
   m_filters = aFilterList;
   m_folders = aFolderList;
   m_filters->GetFilterCount(&m_numFilters);
-  m_folders->Count(&m_numFolders);
+  m_folders->GetLength(&m_numFolders);
 
   NS_ADDREF(this); // we own ourselves, and will release ourselves when execution is done.
 
@@ -426,13 +424,13 @@ nsresult nsMsgFilterAfterTheFact::ApplyFilter(bool *aApplyMore)
     if (m_filters)
       (void)m_filters->GetLoggingEnabled(&loggingEnabled);
 
-    nsCOMPtr<nsISupportsArray> actionList;
-    rv = NS_NewISupportsArray(getter_AddRefs(actionList));
-    NS_ENSURE_SUCCESS(rv, rv);
-    rv = m_curFilter->GetSortedActionList(actionList);
+    nsCOMPtr<nsIArray> actionList;
+
+    rv = m_curFilter->GetSortedActionList(getter_AddRefs(actionList));
     NS_ENSURE_SUCCESS(rv, rv);
+
     uint32_t numActions;
-    actionList->Count(&numActions);
+    actionList->GetLength(&numActions);
 
     // We start from m_nextAction to allow us to continue applying actions
     // after the return from an async copy.
@@ -441,19 +439,21 @@ nsresult nsMsgFilterAfterTheFact::ApplyFilter(bool *aApplyMore)
          actionIndex++)
     {
       nsCOMPtr<nsIMsgRuleAction> filterAction;
-      actionList->QueryElementAt(actionIndex, NS_GET_IID(nsIMsgRuleAction), (void **)getter_AddRefs(filterAction));
+      rv = actionList->QueryElementAt(actionIndex, NS_GET_IID(nsIMsgRuleAction),
+                                                   getter_AddRefs(filterAction));
+      if (NS_FAILED(rv) || !filterAction)
+        continue;
+
       nsMsgRuleActionType actionType;
-      if (filterAction)
-        filterAction->GetType(&actionType);
-      else
+      if (NS_FAILED(filterAction->GetType(&actionType)))
         continue;
 
       nsCString actionTargetFolderUri;
       if (actionType == nsMsgFilterAction::MoveToFolder ||
           actionType == nsMsgFilterAction::CopyToFolder)
       {
-        filterAction->GetTargetFolderUri(actionTargetFolderUri);
-        if (actionTargetFolderUri.IsEmpty())
+        rv = filterAction->GetTargetFolderUri(actionTargetFolderUri);
+        if (NS_FAILED(rv) || actionTargetFolderUri.IsEmpty())
         {
           NS_ASSERTION(false, "actionTargetFolderUri is empty");
           continue;
@@ -790,7 +790,7 @@ NS_IMETHODIMP nsMsgFilterService::GetTempFilterList(nsIMsgFolder *aFolder, nsIMs
   return NS_OK;
 }
 
-NS_IMETHODIMP nsMsgFilterService::ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsISupportsArray *aFolders, nsIMsgWindow *aMsgWindow)
+NS_IMETHODIMP nsMsgFilterService::ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsIArray *aFolders, nsIMsgWindow *aMsgWindow)
 {
   NS_ENSURE_ARG_POINTER(aFilterList);
   NS_ENSURE_ARG_POINTER(aFolders);
@@ -874,7 +874,7 @@ nsMsgFilterService::GetCustomTerm(const nsACString& aId,
 class nsMsgApplyFiltersToMessages : public nsMsgFilterAfterTheFact
 {
 public:
-  nsMsgApplyFiltersToMessages(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsISupportsArray *aFolderList, nsIArray *aMsgHdrList, nsMsgFilterTypeType aFilterType);
+  nsMsgApplyFiltersToMessages(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsIArray *aFolderList, nsIArray *aMsgHdrList, nsMsgFilterTypeType aFilterType);
 
 protected:
   virtual   nsresult  RunNextFilter();
@@ -883,7 +883,7 @@ protected:
   nsMsgFilterTypeType     m_filterType;
 };
 
-nsMsgApplyFiltersToMessages::nsMsgApplyFiltersToMessages(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsISupportsArray *aFolderList, nsIArray *aMsgHdrList, nsMsgFilterTypeType aFilterType)
+nsMsgApplyFiltersToMessages::nsMsgApplyFiltersToMessages(nsIMsgWindow *aMsgWindow, nsIMsgFilterList *aFilterList, nsIArray *aFolderList, nsIArray *aMsgHdrList, nsMsgFilterTypeType aFilterType)
 : nsMsgFilterAfterTheFact(aMsgWindow, aFilterList, aFolderList),
   m_filterType(aFilterType)
 {
@@ -987,10 +987,10 @@ NS_IMETHODIMP nsMsgFilterService::ApplyFilters(nsMsgFilterTypeType aFilterType,
   nsresult rv = aFolder->GetFilterList(aMsgWindow, getter_AddRefs(filterList));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCOMPtr<nsISupportsArray>    folderList;
-  rv = NS_NewISupportsArray( getter_AddRefs(folderList) );
+  nsCOMPtr<nsIMutableArray> folderList(do_CreateInstance(NS_ARRAY_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
-  folderList->AppendElement(aFolder);
+
+  folderList->AppendElement(aFolder, false);
 
   // Create our nsMsgApplyFiltersToMessages object which will be called when ApplyFiltersToHdr
   // finds one or more filters that hit.
