@@ -448,7 +448,7 @@ nsresult nsMessengerWinIntegration::ShowAlertMessage(const nsString& aAlertTitle
                                                 NS_ConvertASCIItoUTF16(aFolderURI), this,
                                                 EmptyString(),
                                                 NS_LITERAL_STRING("auto"),
-                                                EmptyString());
+                                                EmptyString(), nullptr);
       mAlertInProgress = true;
     }
   }
@@ -595,14 +595,14 @@ nsresult nsMessengerWinIntegration::AlertFinished()
 {
   // okay, we are done showing the alert
   // now put an icon in the system tray, if allowed
-  bool showTrayIcon = !mSuppressBiffIcon;
+  bool showTrayIcon = !mSuppressBiffIcon || sBiffIconData.szInfo[0];
   if (showTrayIcon)
   {
     nsCOMPtr<nsIPrefBranch> prefBranch(do_GetService(NS_PREFSERVICE_CONTRACTID));
     if (prefBranch)
       prefBranch->GetBoolPref(SHOW_TRAY_ICON_PREF, &showTrayIcon);
   }
-  if (showTrayIcon || sBiffIconData.szInfo[0])
+  if (showTrayIcon)
   {
     GenericShellNotify(NIM_ADD);
     mBiffIconVisible = true;
@@ -637,6 +637,14 @@ nsresult nsMessengerWinIntegration::AlertClicked()
   return NS_OK;
 }
 
+#ifdef MOZ_SUITE
+nsresult nsMessengerWinIntegration::AlertClickedSimple()
+{
+  mSuppressBiffIcon = true;
+  return NS_OK;
+}
+#endif MOZ_SUITE
+
 NS_IMETHODIMP
 nsMessengerWinIntegration::Observe(nsISupports* aSubject, const char* aTopic, const PRUnichar* aData)
 {
@@ -646,6 +654,13 @@ nsMessengerWinIntegration::Observe(nsISupports* aSubject, const char* aTopic, co
   if (strcmp(aTopic, "alertclickcallback") == 0)
       return AlertClicked();
 
+#ifdef MOZ_SUITE
+  // SeaMonkey does most of the GUI work in JS code when clicking on a mail
+  // notification, so it needs an extra function here
+  if (strcmp(aTopic, "alertclicksimplecallback") == 0)
+      return AlertClickedSimple();
+#endif
+
   return NS_OK;
 }
 
