@@ -1,40 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Seth Spitzer <sspitzer@netscape.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "nsSubscribeDataSource.h"
 
@@ -56,14 +23,6 @@
 
 static NS_DEFINE_CID(kRDFServiceCID, NS_RDFSERVICE_CID);
 
-// this is used for notification of observers using nsVoidArray
-typedef struct _nsSubscribeNotification {
-  nsIRDFDataSource *datasource;
-  nsIRDFResource *subject;
-  nsIRDFResource *property;
-  nsIRDFNode *object;
-} nsSubscribeNotification;
-
 nsSubscribeDataSource::nsSubscribeDataSource()
 {
 }
@@ -72,10 +31,7 @@ nsSubscribeDataSource::~nsSubscribeDataSource()
 {
 }
 
-NS_IMPL_THREADSAFE_ADDREF(nsSubscribeDataSource)
-NS_IMPL_THREADSAFE_RELEASE(nsSubscribeDataSource)
-
-NS_IMPL_QUERY_INTERFACE2(nsSubscribeDataSource, nsIRDFDataSource, nsISubscribeDataSource) 
+NS_IMPL_ISUPPORTS2(nsSubscribeDataSource, nsIRDFDataSource, nsISubscribeDataSource) 
 
 nsresult
 nsSubscribeDataSource::Init()
@@ -122,7 +78,7 @@ nsSubscribeDataSource::Init()
 NS_IMETHODIMP 
 nsSubscribeDataSource::GetURI(char * *aURI)
 {
-  if ((*aURI = strdup("rdf:subscribe")) == nsnull)
+  if ((*aURI = strdup("rdf:subscribe")) == nullptr)
     return NS_ERROR_OUT_OF_MEMORY;
   else
     return NS_OK;
@@ -131,19 +87,19 @@ nsSubscribeDataSource::GetURI(char * *aURI)
 NS_IMETHODIMP 
 nsSubscribeDataSource::GetSource(nsIRDFResource *property, nsIRDFNode *target, bool tv, nsIRDFResource **source)
 {
-    NS_PRECONDITION(property != nsnull, "null ptr");
+    NS_PRECONDITION(property != nullptr, "null ptr");
     if (! property)
         return NS_ERROR_NULL_POINTER;
 
-    NS_PRECONDITION(target != nsnull, "null ptr");
+    NS_PRECONDITION(target != nullptr, "null ptr");
     if (! target)
         return NS_ERROR_NULL_POINTER;
 
-    NS_PRECONDITION(source != nsnull, "null ptr");
+    NS_PRECONDITION(source != nullptr, "null ptr");
     if (! source)
         return NS_ERROR_NULL_POINTER;
 
-    *source = nsnull;
+    *source = nullptr;
     return NS_RDF_NO_VALUE;
 }
 
@@ -155,19 +111,19 @@ nsSubscribeDataSource::GetTarget(nsIRDFResource *source,
 {
 	nsresult rv = NS_RDF_NO_VALUE;
 
-	NS_PRECONDITION(source != nsnull, "null ptr");
+	NS_PRECONDITION(source != nullptr, "null ptr");
 	if (! source)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(property != nsnull, "null ptr");
+	NS_PRECONDITION(property != nullptr, "null ptr");
 	if (! property)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(target != nsnull, "null ptr");
+	NS_PRECONDITION(target != nullptr, "null ptr");
 	if (! target)
 		return NS_ERROR_NULL_POINTER;
 
-	*target = nsnull;
+	*target = nullptr;
 
 	// we only have positive assertions in the subscribe data source.
 	if (! tv) return NS_RDF_NO_VALUE;
@@ -262,19 +218,19 @@ nsSubscribeDataSource::GetTargets(nsIRDFResource *source,
 {
 	nsresult rv = NS_OK;
 
-	NS_PRECONDITION(source != nsnull, "null ptr");
+	NS_PRECONDITION(source != nullptr, "null ptr");
 	if (! source)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(property != nsnull, "null ptr");
+	NS_PRECONDITION(property != nullptr, "null ptr");
 	if (! property)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(targets != nsnull, "null ptr");
+	NS_PRECONDITION(targets != nullptr, "null ptr");
 	if (! targets)
 		return NS_ERROR_NULL_POINTER;
 
-    *targets = nsnull;
+    *targets = nullptr;
 
 	// we only have positive assertions in the subscribe data source.
 	if (!tv) return NS_RDF_NO_VALUE;
@@ -404,7 +360,7 @@ nsSubscribeDataSource::GetServerAndRelativePathFromResource(nsIRDFResource *sour
 {
     nsresult rv = NS_OK;
 
-    const char *sourceURI = nsnull;
+    const char *sourceURI = nullptr;
     rv = source->GetValueConst(&sourceURI);
     NS_ENSURE_SUCCESS(rv,rv);
 
@@ -424,9 +380,9 @@ nsSubscribeDataSource::GetServerAndRelativePathFromResource(nsIRDFResource *sour
     rv = incomingServer->GetServerURI(serverURI);
     NS_ENSURE_SUCCESS(rv,rv);
  
-    PRUint32 serverURILen = serverURI.Length();
+    uint32_t serverURILen = serverURI.Length();
     if (serverURILen == strlen(sourceURI))
-      *relativePath = nsnull;
+      *relativePath = nullptr;
     else {
       // XXX : perhaps, have to unescape before returning 
       *relativePath = strdup(sourceURI + serverURILen + 1);
@@ -446,19 +402,19 @@ nsSubscribeDataSource::HasAssertion(nsIRDFResource *source,
 {
     nsresult rv = NS_OK;
 
-	NS_PRECONDITION(source != nsnull, "null ptr");
+	NS_PRECONDITION(source != nullptr, "null ptr");
 	if (! source)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(property != nsnull, "null ptr");
+	NS_PRECONDITION(property != nullptr, "null ptr");
 	if (! property)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(target != nsnull, "null ptr");
+	NS_PRECONDITION(target != nullptr, "null ptr");
 	if (! target)
 		return NS_ERROR_NULL_POINTER;
 
-	NS_PRECONDITION(hasAssertion != nsnull, "null ptr");
+	NS_PRECONDITION(hasAssertion != nullptr, "null ptr");
 	if (! hasAssertion)
 		return NS_ERROR_NULL_POINTER;
 
@@ -565,11 +521,11 @@ nsSubscribeDataSource::ArcLabelsOut(nsIRDFResource *source,
 {
     nsresult rv = NS_OK;
 
-    NS_PRECONDITION(source != nsnull, "null ptr");
+    NS_PRECONDITION(source != nullptr, "null ptr");
     if (! source)
 	return NS_ERROR_NULL_POINTER;
 
-    NS_PRECONDITION(labels != nsnull, "null ptr");
+    NS_PRECONDITION(labels != nullptr, "null ptr");
     if (! labels)
 	return NS_ERROR_NULL_POINTER;
 
@@ -614,53 +570,26 @@ nsSubscribeDataSource::GetAllResources(nsISimpleEnumerator** aCursor)
 NS_IMETHODIMP
 nsSubscribeDataSource::AddObserver(nsIRDFObserver *n)
 {
-    NS_PRECONDITION(n != nsnull, "null ptr");
-    if (! n)
-        return NS_ERROR_NULL_POINTER;
-
-	if (! mObservers)
-	{
-		nsresult rv;
-		rv = NS_NewISupportsArray(getter_AddRefs(mObservers));
-		if (NS_FAILED(rv)) return rv;
-	}
-	mObservers->AppendElement(n);
-	return NS_OK;
+  NS_ENSURE_ARG_POINTER(n);
+  mObservers.AppendElement(n);
+  return NS_OK;
 }
 
 
 NS_IMETHODIMP
 nsSubscribeDataSource::RemoveObserver(nsIRDFObserver *n)
 {
-    NS_PRECONDITION(n != nsnull, "null ptr");
-    if (! n)
-        return NS_ERROR_NULL_POINTER;
-
-	if (! mObservers)
-		return NS_OK;
-
-	mObservers->RemoveElement(n);
-	return NS_OK;
+  NS_ENSURE_ARG_POINTER(n);
+  mObservers.RemoveElement(n);
+  return NS_OK;
 }
 
 NS_IMETHODIMP
 nsSubscribeDataSource::GetHasObservers(bool *hasObservers)
 {
-    nsresult rv = NS_OK;
-    NS_ASSERTION(hasObservers, "null ptr");
-    if (!hasObservers) return NS_ERROR_NULL_POINTER;
-    
-    if (!mObservers) {
-        *hasObservers = false;
-        return NS_OK;
-    }
-    
-    PRUint32 count = 0;
-    rv = mObservers->Count(&count);
-    NS_ENSURE_SUCCESS(rv,rv);
-
-    *hasObservers = (count > 0);
-    return NS_OK;
+  NS_ENSURE_ARG_POINTER(hasObservers);
+  *hasObservers = !mObservers.IsEmpty();
+  return NS_OK;
 }
 
 NS_IMETHODIMP
@@ -714,63 +643,31 @@ nsSubscribeDataSource::GetSources(nsIRDFResource *aProperty, nsIRDFNode *aTarget
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+#define NOTIFY_SUBSCRIBE_LISTENERS(propertyfunc_, params_) \
+  PR_BEGIN_MACRO \
+  { \
+    nsTObserverArray<nsCOMPtr<nsIRDFObserver> >::ForwardIterator iter(mObservers); \
+    while (iter.HasMore()) \
+    { \
+      iter.GetNext()->propertyfunc_ params_; \
+    } \
+  } \
+  PR_END_MACRO
+
 NS_IMETHODIMP
 nsSubscribeDataSource::NotifyObservers(nsIRDFResource *subject,
                                                 nsIRDFResource *property,
                                                 nsIRDFNode *object,
                                                 bool assert, bool change)
 {
-    NS_ASSERTION(!(change && assert),
-                 "Can't change and assert at the same time!\n");
+  NS_ASSERTION(!(change && assert),
+               "Can't change and assert at the same time!\n");
 
-    if(mObservers)
-    {
-        nsSubscribeNotification note = { this, subject, property, object };
-        if(change)
-            mObservers->EnumerateForwards(changeEnumFunc, &note);
-        else if (assert)
-            mObservers->EnumerateForwards(assertEnumFunc, &note);
-        else
-            mObservers->EnumerateForwards(unassertEnumFunc, &note);
-  }
-    return NS_OK;
-}
-
-bool
-nsSubscribeDataSource::changeEnumFunc(nsISupports *aElement, void *aData)
-{
-  nsSubscribeNotification* note = (nsSubscribeNotification*)aData;
-  nsIRDFObserver* observer = (nsIRDFObserver *)aElement;
-
-  observer->OnChange(note->datasource,
-                     note->subject,
-                     note->property,
-                     nsnull, note->object);
-  return true;
-}
-
-bool
-nsSubscribeDataSource::assertEnumFunc(nsISupports *aElement, void *aData)
-{
-  nsSubscribeNotification* note = (nsSubscribeNotification*)aData;
-  nsIRDFObserver* observer = (nsIRDFObserver *)aElement;
-
-  observer->OnAssert(note->datasource,
-                     note->subject,
-                     note->property,
-                     note->object);
-  return true;
-}
-
-bool
-nsSubscribeDataSource::unassertEnumFunc(nsISupports *aElement, void *aData)
-{
-  nsSubscribeNotification* note = (nsSubscribeNotification*)aData;
-  nsIRDFObserver* observer = (nsIRDFObserver *)aElement;
-
-  observer->OnUnassert(note->datasource,
-                       note->subject,
-                       note->property,
-                       note->object);
-  return true;
+  if (change)
+    NOTIFY_SUBSCRIBE_LISTENERS(OnChange, (this, subject, property, nullptr, object));
+  else if (assert)
+    NOTIFY_SUBSCRIBE_LISTENERS(OnAssert, (this, subject, property, object));
+  else
+    NOTIFY_SUBSCRIBE_LISTENERS(OnUnassert, (this, subject, property, object));
+  return NS_OK;
 }
