@@ -25,6 +25,7 @@
 #include "nsUConvCID.h"
 #include "nsAutoPtr.h"
 #include "nsComposeStrings.h"
+#include "nsIAsyncInputStream.h"
 
 #define SERVER_DELIMITER ','
 #define APPEND_SERVERS_VERSION_PREF_NAME "append_preconfig_smtpservers.version"
@@ -90,7 +91,7 @@ NS_IMETHODIMP nsSmtpService::SendMailMessage(nsIFile * aFilePath,
   nsresult rv = NS_OK;
 
   nsCOMPtr<nsISmtpServer> smtpServer;
-  rv = GetSmtpServerByIdentity(aSenderIdentity, getter_AddRefs(smtpServer));
+  rv = GetServerByIdentity(aSenderIdentity, getter_AddRefs(smtpServer));
 
   if (NS_SUCCEEDED(rv) && smtpServer)
   {
@@ -178,7 +179,8 @@ nsresult NS_MsgBuildSmtpUrl(nsIFile * aFilePath,
   smtpUrl->SetRequestDSN(aRequestDSN);
   smtpUrl->SetPostMessageFile(aFilePath);
   smtpUrl->SetSenderIdentity(aSenderIdentity);
-  smtpUrl->SetNotificationCallbacks(aNotificationCallbacks);
+  if (aNotificationCallbacks)
+    smtpUrl->SetNotificationCallbacks(aNotificationCallbacks);
   smtpUrl->SetSmtpServer(aSmtpServer);
 
   nsCOMPtr<nsIPrompt> smtpPrompt(do_GetInterface(aNotificationCallbacks));
@@ -197,7 +199,8 @@ nsresult NS_MsgBuildSmtpUrl(nsIFile * aFilePath,
   smtpUrl->SetPrompt(smtpPrompt);            
   smtpUrl->SetAuthPrompt(smtpAuthPrompt);
 
-  url->RegisterListener(aUrlListener);
+  if (aUrlListener)
+    url->RegisterListener(aUrlListener);
   if (aStatusFeedback)
     url->SetStatusFeedback(aStatusFeedback);
 
@@ -337,7 +340,7 @@ NS_IMETHODIMP nsSmtpService::NewChannel(nsIURI *aURI, nsIChannel **_retval)
 
 
 NS_IMETHODIMP
-nsSmtpService::GetSmtpServers(nsISimpleEnumerator **aResult)
+nsSmtpService::GetServers(nsISimpleEnumerator **aResult)
 {
   NS_ENSURE_ARG_POINTER(aResult);
 
@@ -576,7 +579,7 @@ nsSmtpService::findServerByKey(nsISmtpServer *aServer, void *aData)
 }
 
 NS_IMETHODIMP
-nsSmtpService::CreateSmtpServer(nsISmtpServer **aResult)
+nsSmtpService::CreateServer(nsISmtpServer **aResult)
 {
     if (!aResult) return NS_ERROR_NULL_POINTER;
 
@@ -630,7 +633,7 @@ nsSmtpService::GetServerByKey(const char* aKey, nsISmtpServer **aResult)
 }
 
 NS_IMETHODIMP
-nsSmtpService::DeleteSmtpServer(nsISmtpServer *aServer)
+nsSmtpService::DeleteServer(nsISmtpServer *aServer)
 {
     if (!aServer) return NS_OK;
 
@@ -723,7 +726,8 @@ nsSmtpService::FindServer(const char *aUsername,
 }
 
 NS_IMETHODIMP
-nsSmtpService::GetSmtpServerByIdentity(nsIMsgIdentity *aSenderIdentity, nsISmtpServer **aSmtpServer)
+nsSmtpService::GetServerByIdentity(nsIMsgIdentity *aSenderIdentity,
+                                   nsISmtpServer **aSmtpServer)
 {
   NS_ENSURE_ARG_POINTER(aSmtpServer);
   nsresult rv = NS_ERROR_FAILURE;
