@@ -214,10 +214,10 @@ nsDBFolderInfo::nsDBFolderInfo(nsMsgDatabase *mdb)
 
     //		mdb->AddRef();
     err = m_mdb->GetStore()->StringToToken(mdb->GetEnv(), kDBFolderInfoScope, &m_rowScopeToken);
-    if (err == NS_OK)
+    if (NS_SUCCEEDED(err))
     {
       err = m_mdb->GetStore()->StringToToken(mdb->GetEnv(), kDBFolderInfoTableKind, &m_tableKindToken);
-      if (err == NS_OK)
+      if (NS_SUCCEEDED(err))
       {
         gDBFolderInfoOID.mOid_Scope = m_rowScopeToken;
         gDBFolderInfoOID.mOid_Id = 1;
@@ -264,11 +264,6 @@ nsresult nsDBFolderInfo::AddToNewMDB()
     mdb_err err = store->NewTable(m_mdb->GetEnv(), m_rowScopeToken,
       m_tableKindToken, true, nullptr, &m_mdbTable);
 
-    // make sure the oid of the table is 1.
-    struct mdbOid folderInfoTableOID;
-    folderInfoTableOID.mOid_Id = 1;
-    folderInfoTableOID.mOid_Scope = m_rowScopeToken;
-
     // create the singleton row for the dbFolderInfo.
     err  = store->NewRowWithOid(m_mdb->GetEnv(),
       &gDBFolderInfoOID, &m_mdbRow);
@@ -302,18 +297,18 @@ nsresult nsDBFolderInfo::InitFromExistingDB()
       {
         // find singleton row for global info.
         ret = m_mdbTable->HasOid(m_mdb->GetEnv(), &gDBFolderInfoOID, &hasOid);
-        if (ret == NS_OK)
+        if (NS_SUCCEEDED(ret))
         {
           nsIMdbTableRowCursor *rowCursor;
           rowPos = -1;
           ret= m_mdbTable->GetTableRowCursor(m_mdb->GetEnv(), rowPos, &rowCursor);
-          if (ret == NS_OK)
+          if (NS_SUCCEEDED(ret))
           {
             ret = rowCursor->NextRow(m_mdb->GetEnv(), &m_mdbRow, &rowPos);
             NS_RELEASE(rowCursor);
             if (!m_mdbRow)
               ret = NS_ERROR_FAILURE;
-            if (ret == NS_OK)
+            if (NS_SUCCEEDED(ret))
               LoadMemberVariables();
           }
         }
