@@ -16,11 +16,20 @@ FeedParser.prototype =
   // parseFeed returns an empty feed in addition to calling aFeed.onParseError.
   parseFeed: function (aFeed, aDOM, aBaseURI)
   {
-    let doc = aDOM.documentElement;
-    if (!(aDOM instanceof Ci.nsIDOMXMLDocument) ||
-        doc.getElementsByTagNameNS(FeedUtils.MOZ_PARSERERROR_NS, "parsererror")[0])
+    if (!(aDOM instanceof Ci.nsIDOMXMLDocument))
     {
-      // No xml doc or gecko caught a basic parsing error.
+      // No xml doc.
+      aFeed.onParseError(aFeed);
+      return new Array();
+    }
+
+    let doc = aDOM.documentElement;
+    if (doc.namespaceURI == FeedUtils.MOZ_PARSERERROR_NS)
+    {
+      // Gecko caught a basic parsing error.
+      let errStr = doc.firstChild.textContent + "\n" +
+                   doc.firstElementChild.textContent;
+      FeedUtils.log.info("FeedParser.parseFeed: - " + errStr);
       aFeed.onParseError(aFeed);
       return new Array();
     }
@@ -94,6 +103,13 @@ FeedParser.prototype =
     tags = this.childrenByTagNameNS(channel, nsURI, "link");
     aFeed.link = this.getNodeValue(tags ? tags[0] : null);
 
+    if (!(aFeed.title || aFeed.description) || !aFeed.link)
+    {
+      FeedUtils.log.error("FeedParser.parseAsRSS2: missing mandatory element " +
+                          "<title> and <description>, or <link>");
+      return aFeed.onParseError(aFeed);
+    }
+
     if (!aFeed.parseItems)
       return parsedItems;
 
@@ -105,12 +121,12 @@ FeedParser.prototype =
     FeedUtils.log.debug("FeedParser.parseAsRSS2: items to parse - " +
                         itemNodes.length);
 
-    for (let i = 0; i < itemNodes.length; i++)
+    for (let itemNode of itemNodes)
     {
-      let itemNode = itemNodes[i];
+      if (!itemNode.childElementCount)
+        continue;
       let item = new FeedItem();
       item.feed = aFeed;
-      item.characterSet = "UTF-8";
       item.enclosures = [];
 
       tags = this.childrenByTagNameNS(itemNode, nsURI, "link");
@@ -146,17 +162,35 @@ FeedParser.prototype =
         }
 
         item.id = guid;
-        item.isStoredWithId = true;
       }
 
       item.url = (guid && isPermaLink) ? guid : link ? link : null;
       tags = this.childrenByTagNameNS(itemNode, nsURI, "description");
       item.description = this.getNodeValue(tags ? tags[0] : null);
       tags = this.childrenByTagNameNS(itemNode, nsURI, "title");
-      item.title = this.getNodeValue(tags ? tags[0] : null) ||
-                   (item.description ?
-                      this.stripTags(item.description).substr(0, 150) : null) ||
-                   item.title;
+      item.title = this.getNodeValue(tags ? tags[0] : null);
+      if (!(item.title || item.description))
+      {
+        FeedUtils.log.info("FeedParser.parseAsRSS2: <item> missing mandatory " +
+                           "element, either <title> or <description>; skipping");
+        continue;
+      }
+
+      if (!item.id)
+      {
+        // At this point, if there is no guid, uniqueness cannot be guaranteed
+        // by any of link or date (optional) or title (optional unless there
+        // is no description). Use a big chunk of description; minimize dupes
+        // with url and title if present.
+        item.id = (item.url || item.feed.url) + "#" + item.title + "#" +
+                  (this.stripTags(item.description ?
+                                    item.description.substr(0, 150) : null) ||
+                   item.title);
+        item.id = item.id.replace(/[\n\r\t\s]+/g, " ");
+      }
+
+      if (!item.title)
+        item.title = this.stripTags(item.description).substr(0, 150);
 
       tags = this.childrenByTagNameNS(itemNode, nsURI, "author");
       if (!tags)
@@ -166,20 +200,17 @@ FeedParser.prototype =
                     item.author;
 
       tags = this.childrenByTagNameNS(itemNode, nsURI, "pubDate");
-      if (!tags)
+      if (!tags || !this.getNodeValue(tags[0]))
         tags = this.childrenByTagNameNS(itemNode, FeedUtils.DC_NS, "date");
       item.date = this.getNodeValue(tags ? tags[0] : null) || item.date;
 
-      if (!item.id)
-        item.id = item.feed.url + "#" + (item.date || item.title);
-
       // If the date is invalid, users will see the beginning of the epoch
       // unless we reset it here, so they'll see the current time instead.
       // This is typical aggregator behavior.
       if (item.date)
       {
         item.date = item.date.trim();
-        if (!this.isValidRFC822Date(item.date))
+        if (!FeedUtils.isValidRFC822Date(item.date))
         {
           // XXX Use this on the other formats as well.
           item.date = this.dateRescue(item.date);
@@ -194,9 +225,8 @@ FeedParser.prototype =
       tags = this.childrenByTagNameNS(itemNode, nsURI, "enclosure");
       let encUrls = [];
       if (tags)
-        for (let j = 0; j < tags.length; j++)
+        for (let tag of tags)
         {
-          let tag = tags[j];
           let url = tag.getAttribute("url");
           if (url)
           {
@@ -209,9 +239,8 @@ FeedParser.prototype =
 
       tags = itemNode.getElementsByTagNameNS(FeedUtils.MRSS_NS, "content");
       if (tags)
-        for (let j = 0; j < tags.length; j++)
+        for (let tag of tags)
         {
-          let tag = tags[j];
           let url = tag.getAttribute("url");
           if (url && encUrls.indexOf(url) == -1)
             item.enclosures.push(new FeedEnclosure(url,
@@ -219,7 +248,7 @@ FeedParser.prototype =
                                                    tag.getAttribute("fileSize")));
         }
 
-      parsedItems[i] = item;
+      parsedItems.push(item);
     }
 
     return parsedItems;
@@ -240,6 +269,8 @@ FeedParser.prototype =
 
     // Get information about the feed as a whole.
     let channel = ds.GetSource(FeedUtils.RDF_TYPE, FeedUtils.RSS_CHANNEL, true);
+    if (!channel)
+      return aFeed.onParseError(aFeed);
 
     aFeed.title = aFeed.title ||
                   this.getRDFTargetValue(ds, channel, FeedUtils.RSS_TITLE) ||
@@ -249,19 +280,20 @@ FeedParser.prototype =
     aFeed.link = this.getRDFTargetValue(ds, channel, FeedUtils.RSS_LINK) ||
                  aFeed.url;
 
+    if (!(aFeed.title || aFeed.description) || !aFeed.link)
+    {
+      FeedUtils.log.error("FeedParser.parseAsRSS1: missing mandatory element " +
+                          "<title> and <description>, or <link>");
+      return aFeed.onParseError(aFeed);
+    }
+
     if (!aFeed.parseItems)
       return parsedItems;
 
     aFeed.invalidateItems();
 
-    let items = ds.GetTarget(channel, FeedUtils.RSS_ITEMS, true);
-    if (items)
-      items = FeedUtils.rdfContainerUtils.MakeSeq(ds, items).GetElements();
- 
-    // If the channel doesn't list any items, look for resources of type "item"
-    // (a hacky workaround for some buggy feeds).
-    if (!items || !items.hasMoreElements())
-      items = ds.GetSources(FeedUtils.RDF_TYPE, FeedUtils.RSS_ITEM, true);
+    // Ignore the <items> list and just get the <item>s.
+    let items = ds.GetSources(FeedUtils.RDF_TYPE, FeedUtils.RSS_ITEM, true);
 
     let index = 0;
     while (items.hasMoreElements())
@@ -269,26 +301,28 @@ FeedParser.prototype =
       let itemResource = items.getNext().QueryInterface(Ci.nsIRDFResource);
       let item = new FeedItem();
       item.feed = aFeed;
-      item.characterSet = "UTF-8";
 
       // Prefer the value of the link tag to the item URI since the URI could be
       // a relative URN.
       let uri = itemResource.Value;
       let link = this.getRDFTargetValue(ds, itemResource, FeedUtils.RSS_LINK);
-
-      // XXX Check for bug258465 - entities appear escaped  in the value
-      // returned by getRDFTargetValue when they shouldn't.
-      //debug("link comparison\n" + " uri: " + uri + "\nlink: " + link);
-
       item.url = link || uri;
-      item.id = item.url;
       item.description = this.getRDFTargetValue(ds, itemResource,
                                                 FeedUtils.RSS_DESCRIPTION);
       item.title = this.getRDFTargetValue(ds, itemResource, FeedUtils.RSS_TITLE) ||
                    this.getRDFTargetValue(ds, itemResource, FeedUtils.DC_SUBJECT) ||
                    (item.description ?
-                     (this.stripTags(item.description).substr(0, 150)) : null) ||
-                   item.title;
+                     (this.stripTags(item.description).substr(0, 150)) : null);
+      if (!item.url || !item.title)
+      {
+        FeedUtils.log.info("FeedParser.parseAsRSS1: <item> missing mandatory " +
+                           "element <item rdf:about> and <link>, or <title> and " +
+                           "no <description>; skipping");
+        continue;
+      }
+
+      item.id = item.url;
+
       item.author = this.getRDFTargetValue(ds, itemResource, FeedUtils.DC_CREATOR) ||
                     this.getRDFTargetValue(ds, channel, FeedUtils.DC_CREATOR) ||
                     aFeed.title ||
@@ -312,10 +346,7 @@ FeedParser.prototype =
     // Get the first channel (assuming there is only one per Atom File).
     let channel = aDOM.querySelector("feed");
     if (!channel)
-    {
-      aFeed.onParseError(aFeed);
-      return parsedItems;
-    }
+      return aFeed.onParseError(aFeed);
 
     let tags = this.childrenByTagNameNS(channel, FeedUtils.ATOM_03_NS, "title");
     aFeed.title = aFeed.title ||
@@ -325,6 +356,13 @@ FeedParser.prototype =
     tags = this.childrenByTagNameNS(channel, FeedUtils.ATOM_03_NS, "link");
     aFeed.link = this.findAtomLink("alternate", tags);
 
+    if (!aFeed.title)
+    {
+      FeedUtils.log.error("FeedParser.parseAsAtom: missing mandatory element " +
+                          "<title>");
+      return aFeed.onParseError(aFeed);
+    }
+
     if (!aFeed.parseItems)
       return parsedItems;
 
@@ -334,12 +372,12 @@ FeedParser.prototype =
     FeedUtils.log.debug("FeedParser.parseAsAtom: items to parse - " +
                         items.length);
 
-    for (let i = 0; i < items.length; i++)
+    for (let itemNode of items)
     {
-      let itemNode = items[i];
+      if (!itemNode.childElementCount)
+        continue;
       let item = new FeedItem();
       item.feed = aFeed;
-      item.characterSet = "UTF-8";
 
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_03_NS, "link");
       item.url = this.findAtomLink("alternate", tags);
@@ -350,8 +388,14 @@ FeedParser.prototype =
       item.description = this.getNodeValue(tags ? tags[0] : null);
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_03_NS, "title");
       item.title = this.getNodeValue(tags ? tags[0] : null) ||
-                   (item.description ? item.description.substr(0, 150) : null) ||
-                   item.title;
+                   (item.description ? item.description.substr(0, 150) : null);
+      if (!item.title || !item.id)
+      {
+        // We're lenient about other mandatory tags, but insist on these.
+        FeedUtils.log.info("FeedParser.parseAsAtom: <entry> missing mandatory " +
+                           "element <id>, or <title> and no <summary>; skipping");
+        continue;
+      }
 
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_03_NS, "author");
       if (!tags)
@@ -377,9 +421,9 @@ FeedParser.prototype =
       item.author = author || item.author || aFeed.title;
 
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_03_NS, "modified");
-      if (!tags)
+      if (!tags || !this.getNodeValue(tags[0]))
         tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_03_NS, "issued");
-      if (!tags)
+      if (!tags || !this.getNodeValue(tags[0]))
         tags = this.childrenByTagNameNS(channel, FeedUtils.ATOM_03_NS, "created");
 
       item.date = this.getNodeValue(tags ? tags[0] : null) || item.date;
@@ -420,7 +464,7 @@ FeedParser.prototype =
       }
 
       item.content = content;
-      parsedItems[i] = item;
+      parsedItems.push(item);
     }
 
     return parsedItems;
@@ -433,10 +477,7 @@ FeedParser.prototype =
     // Get the first channel (assuming there is only one per Atom File).
     let channel = this.childrenByTagNameNS(aDOM, FeedUtils.ATOM_IETF_NS, "feed")[0];
     if (!channel)
-    {
-      aFeed.onParseError(aFeed);
-      return parsedItems;
-    }
+      return aFeed.onParseError(aFeed);
 
     let tags = this.childrenByTagNameNS(channel, FeedUtils.ATOM_IETF_NS, "title");
     aFeed.title = aFeed.title ||
@@ -448,6 +489,13 @@ FeedParser.prototype =
     tags = this.childrenByTagNameNS(channel, FeedUtils.ATOM_IETF_NS, "link");
     aFeed.link = this.findAtomLink("alternate", tags);
 
+    if (!aFeed.title)
+    {
+      FeedUtils.log.error("FeedParser.parseAsAtomIETF: missing mandatory element " +
+                          "<title>");
+      return aFeed.onParseError(aFeed);
+    }
+
     if (!aFeed.parseItems)
       return parsedItems;
 
@@ -457,13 +505,12 @@ FeedParser.prototype =
     FeedUtils.log.debug("FeedParser.parseAsAtomIETF: items to parse - " +
                         items.length);
 
-    for (let i = 0; i < items.length; i++)
+    for (let itemNode of items)
     {
-      let itemNode = items[i];
+      if (!itemNode.childElementCount)
+        continue;
       let item = new FeedItem();
       item.feed = aFeed;
-      item.characterSet = "UTF-8";
-      item.isStoredWithId = true;
       item.enclosures = [];
 
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "link");
@@ -475,15 +522,21 @@ FeedParser.prototype =
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "title");
       item.title = this.stripTags(this.serializeTextConstruct(tags ? tags[0] : null) ||
                                   (item.description ?
-                                     item.description.substr(0, 150) : null) ||
-                                  item.title);
+                                     item.description.substr(0, 150) : null));
+      if (!item.title || !item.id)
+      {
+        // We're lenient about other mandatory tags, but insist on these.
+        FeedUtils.log.info("FeedParser.parseAsAtom: <entry> missing mandatory " +
+                           "element <id>, or <title> and no <summary>; skipping");
+        continue;
+      }
 
       // XXX Support multiple authors.
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "source");
       let source = tags ? tags[0] : null;
 
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "author");
-      if (!tags && source)
+      if (!tags)
         tags = this.childrenByTagNameNS(source, FeedUtils.ATOM_IETF_NS, "author");
       if (!tags)
         tags = this.childrenByTagNameNS(channel, FeedUtils.ATOM_IETF_NS, "author");
@@ -506,7 +559,9 @@ FeedParser.prototype =
       item.author = author || item.author || aFeed.title;
 
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "updated");
-      if (!tags && source)
+      if (!tags || !this.getNodeValue(tags[0]))
+        tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "published");
+      if (!tags || !this.getNodeValue(tags[0]))
         tags = this.childrenByTagNameNS(source, FeedUtils.ATOM_IETF_NS, "published");
       item.date = this.getNodeValue(tags ? tags[0] : null) || item.date;
 
@@ -526,9 +581,8 @@ FeedParser.prototype =
       // Handle <link rel="enclosure"> (if present).
       tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_IETF_NS, "link");
       if (tags)
-        for (let j = 0; j < tags.length; j++)
+        for (let tag of tags)
         {
-          let tag = tags[j];
           if (tag.getAttribute("rel") == "enclosure" && tag.getAttribute("href"))
             item.enclosures.push(new FeedEnclosure(tag.getAttribute("href"),
                                                    tag.getAttribute("type"),
@@ -536,7 +590,22 @@ FeedParser.prototype =
                                                    tag.getAttribute("title")));
         }
 
-      parsedItems[i] = item;
+      // Handle atom threading extension, RFC4685.  There may be 1 or more tags,
+      // and each must contain a ref attribute with 1 Message-Id equivalent
+      // value.  This is the only attr of interest in the spec for presentation.
+      tags = this.childrenByTagNameNS(itemNode, FeedUtils.ATOM_THREAD_NS, "in-reply-to");
+      if (tags)
+      {
+        for (let tag of tags)
+        {
+          let ref = tag.getAttribute("ref");
+          if (ref)
+            item.inReplyTo += item.normalizeMessageID(ref) + " ";
+        }
+        item.inReplyTo = item.inReplyTo.trimRight();
+      }
+
+      parsedItems.push(item);
     }
 
     return parsedItems;
@@ -568,6 +637,8 @@ FeedParser.prototype =
 
       if (textType == "html")
         content = this.xmlUnescape(content);
+
+      content = content.trim();
     }
 
     // Other parts of the code depend on this being null if there's no content.
@@ -583,7 +654,7 @@ FeedParser.prototype =
       {
         node = node.QueryInterface(Ci.nsIRDFLiteral);
         if (node)
-          return node.Value;
+          return node.Value.trim();
       }
       catch (e)
       {
@@ -621,12 +692,14 @@ FeedParser.prototype =
   // Finds elements that are direct children of the first arg.
   childrenByTagNameNS: function(aElement, aNamespace, aTagName)
   {
+    if (!aElement)
+      return null;
     let matches = aElement.getElementsByTagNameNS(aNamespace, aTagName);
     let matchingChildren = new Array();
-    for (let i = 0; i < matches.length; i++)
+    for (let match of matches)
     {
-      if (matches[i].parentNode == aElement)
-        matchingChildren.push(matches[i])
+      if (match.parentNode == aElement)
+        matchingChildren.push(match)
     }
 
     return matchingChildren.length ? matchingChildren : null;
@@ -638,8 +711,7 @@ FeedParser.prototype =
       return null;
 
     // XXX Need to check for MIME type and hreflang.
-    for (let j = 0; j < linkElements.length; j++) {
-      let alink = linkElements[j];
+    for (let alink of linkElements) {
       if (alink &&
           // If there's a link rel.
           ((alink.getAttribute("rel") && alink.getAttribute("rel") == linkRel) ||
@@ -680,18 +752,6 @@ FeedParser.prototype =
     return s;
   },
 
-  // Date validator for RSS feeds
-  FZ_RFC822_RE: "^(((Mon)|(Tue)|(Wed)|(Thu)|(Fri)|(Sat)|(Sun)), *)?\\d\\d?" +
-    " +((Jan)|(Feb)|(Mar)|(Apr)|(May)|(Jun)|(Jul)|(Aug)|(Sep)|(Oct)|(Nov)|(Dec))" +
-    " +\\d\\d(\\d\\d)? +\\d\\d:\\d\\d(:\\d\\d)? +(([+-]?\\d\\d\\d\\d)|(UT)|(GMT)" +
-    "|(EST)|(EDT)|(CST)|(CDT)|(MST)|(MDT)|(PST)|(PDT)|\\w)$",
-
-  isValidRFC822Date: function(pubDate)
-  {
-    let regex = new RegExp(this.FZ_RFC822_RE);
-    return regex.test(pubDate);
-  },
-
   dateRescue: function(dateString)
   {
     // Deal with various kinds of invalid dates.
@@ -708,11 +768,7 @@ FeedParser.prototype =
         return d.toString();
     }
 
-    if (dateString.search(/^\d\d\d\d/) != -1)
-      //Could be an ISO8601/W3C date.
-      return new Date(dateString).toUTCString();
-
-    // Can't help.  Set to current time.
-    return (new Date()).toString();
+    // Could be an ISO8601/W3C date.  If not, get the current time.
+    return FeedUtils.getValidRFC5322Date(dateString);
   }
 };
