@@ -41,7 +41,7 @@ public:
   nsImportGenericAddressBooks();
   virtual ~nsImportGenericAddressBooks();
 
-  NS_DECL_ISUPPORTS
+  NS_DECL_THREADSAFE_ISUPPORTS
 
   /* nsISupports GetData (in string dataId); */
   NS_IMETHOD GetData(const char *dataId, nsISupports **_retval);
@@ -170,7 +170,7 @@ nsImportGenericAddressBooks::~nsImportGenericAddressBooks()
 
 
 
-NS_IMPL_THREADSAFE_ISUPPORTS1(nsImportGenericAddressBooks, nsIImportGeneric)
+NS_IMPL_ISUPPORTS1(nsImportGenericAddressBooks, nsIImportGeneric)
 
 
 NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISupports **_retval)
@@ -430,31 +430,30 @@ void nsImportGenericAddressBooks::GetDefaultFieldMap(void)
 NS_IMETHODIMP nsImportGenericAddressBooks::WantsProgress(bool *_retval)
 {
   NS_PRECONDITION(_retval != nullptr, "null ptr");
-    if (!_retval)
-        return NS_ERROR_NULL_POINTER;
+  NS_ENSURE_ARG_POINTER(_retval);
 
   GetDefaultLocation();
   GetDefaultBooks();
 
-  uint32_t    totalSize = 0;
-  bool        result = false;
+  bool result = false;
 
   if (m_pBooks) {
     uint32_t    count = 0;
-    nsresult     rv = m_pBooks->Count(&count);
     uint32_t    i;
     bool        import;
     uint32_t    size;
+    uint32_t    totalSize = 0;
+
+    (void) m_pBooks->Count(&count);
 
     for (i = 0; i < count; i++) {
-      nsCOMPtr<nsIImportABDescriptor> book =
-        do_QueryElementAt(m_pBooks, i);
+      nsCOMPtr<nsIImportABDescriptor> book = do_QueryElementAt(m_pBooks, i);
       if (book) {
         import = false;
         size = 0;
-        rv = book->GetImport(&import);
-        if (import) {
-          rv = book->GetSize(&size);
+        nsresult rv = book->GetImport(&import);
+        if (NS_SUCCEEDED(rv) && import) {
+          (void) book->GetSize(&size);
           result = true;
         }
         totalSize += size;
@@ -505,9 +504,9 @@ already_AddRefed<nsIAddrDatabase> GetAddressBookFromUri(const char *pUri)
   if (!mdbDirectory)
     return nullptr;
 
-  nsIAddrDatabase *pDatabase = nullptr;
-  mdbDirectory->GetDatabase(&pDatabase);
-  return pDatabase;
+  nsCOMPtr<nsIAddrDatabase> pDatabase;
+  mdbDirectory->GetDatabase(getter_AddRefs(pDatabase));
+  return pDatabase.forget();
 }
 
 already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
@@ -522,7 +521,7 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
   IMPORT_LOG0("In GetAddressBook\n");
 
   nsresult rv;
-  nsIAddrDatabase *pDatabase = nullptr;
+  nsCOMPtr<nsIAddrDatabase> pDatabase;
   nsCOMPtr<nsIFile> dbPath;
   nsCOMPtr<nsIAbManager> abManager = do_GetService(NS_ABMANAGER_CONTRACTID, &rv);
   if (NS_SUCCEEDED(rv))
@@ -549,7 +548,7 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
 
           IMPORT_LOG0("Opening the new address book\n");
           rv = addrDBFactory->Open(dbPath, true, true,
-                                   &pDatabase);
+                                   getter_AddRefs(pDatabase));
         }
       }
     }
@@ -590,7 +589,7 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
       IMPORT_LOG0("*** Error: An error occurred while adding the address book to the UI\n");
   }
 
-  return pDatabase;
+  return pDatabase.forget();
 }
 
 NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval)
@@ -804,8 +803,7 @@ static void ImportAddressThread(void *stuff)
   IMPORT_LOG0("In Begin ImportAddressThread\n");
 
   AddressThreadData *pData = (AddressThreadData *)stuff;
-  uint32_t  count = 0;
-  nsresult   rv = pData->books->Count(&count);
+  uint32_t          count = 0;
   uint32_t          i;
   bool              import;
   uint32_t          size;
@@ -813,17 +811,20 @@ static void ImportAddressThread(void *stuff)
   nsString          success;
   nsString          error;
 
+  (void) pData->books->Count(&count);
+
   for (i = 0; (i < count) && !(pData->abort); i++) {
     nsCOMPtr<nsIImportABDescriptor> book =
       do_QueryElementAt(pData->books, i);
+
     if (book) {
       import = false;
       size = 0;
-      rv = book->GetImport(&import);
-      if (import)
+      nsresult rv = book->GetImport(&import);
+      if (NS_SUCCEEDED(rv) && import)
         rv = book->GetSize(&size);
 
-      if (size && import) {
+      if (NS_SUCCEEDED(rv) && size && import) {
         nsString name;
         book->GetPreferredName(name);
 
@@ -857,7 +858,7 @@ static void ImportAddressThread(void *stuff)
                                                        &pError,
                                                        &pSuccess,
                                                        &fatalError);
-          if (pSuccess) {
+          if (NS_SUCCEEDED(rv) && pSuccess) {
             success.Append(pSuccess);
             NS_Free(pSuccess);
           }
