@@ -480,6 +480,7 @@ mime_draft_process_attachments(mime_draft_data *mdd)
   //It's possible we must treat the message body as attachment!
   bool bodyAsAttachment = false;
   if (mdd->messageBody &&
+      !mdd->messageBody->m_type.IsEmpty() &&
       mdd->messageBody->m_type.Find("text/html", CaseInsensitiveCompare) == -1 &&
       mdd->messageBody->m_type.Find("text/plain", CaseInsensitiveCompare) == -1 &&
       !mdd->messageBody->m_type.LowerCaseEqualsLiteral("text"))
@@ -1303,6 +1304,12 @@ mime_parse_stream_complete (nsMIMESession *stream)
       if (parm)
         sscanf(parm, "%d", &lineWidth);
       PR_FREEIF(parm);
+      parm = MimeHeaders_get_parameter(draftInfo, "attachmentreminder", NULL, NULL);
+      if (parm && !strcmp(parm, "1"))
+        fields->SetAttachmentReminder(true);
+      else
+        fields->SetAttachmentReminder(false);
+      PR_FREEIF(parm);
 
     }
 
