@@ -32,6 +32,7 @@
 #include "nsISimpleEnumerator.h"
 #include "nsMsgUtils.h"
 #include "mozilla/Services.h"
+#include "nsITreeBoxObject.h"
 
 #define INVALID_VERSION         0
 #define VALID_VERSION           2
@@ -73,7 +74,7 @@ public:
 
   bool LessThan(const nsCString &a, const nsCString &b) const
   {
-    return Compare(a, b, nsCaseInsensitiveCStringComparator());
+    return Compare(a, b, nsCaseInsensitiveCStringComparator()) < 0;
   }
 };
 
@@ -1073,7 +1074,7 @@ NS_IMETHODIMP
 nsNntpIncomingServer::SetAsSubscribed(const nsACString &path)
 {
     mTempSubscribed.AppendElement(path);
-    if (mGetOnlyNew && (mGroupsOnServer.IndexOf(path) == mGroupsOnServer.NoIndex))
+    if (mGetOnlyNew && (!mGroupsOnServer.Contains(path)))
       return NS_OK;
 
     nsresult rv = EnsureInner();
@@ -1568,7 +1569,7 @@ nsNntpIncomingServer::GroupNotFound(nsIMsgWindow *aMsgWindow,
   NS_ENSURE_SUCCESS(rv,rv);
 
   nsCString hostname;
-  rv = GetHostName(hostname);
+  rv = GetRealHostName(hostname);
   NS_ENSURE_SUCCESS(rv,rv);
 
   NS_ConvertUTF8toUTF16 hostStr(hostname);
@@ -1650,20 +1651,34 @@ nsNntpIncomingServer::GetCanCreateFoldersOnServer(bool *aCanCreateFoldersOnServe
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::SetSearchValue(const nsAString &searchValue)
+nsNntpIncomingServer::SetSearchValue(const nsAString &aSearchValue)
 {
-  mSearchValue = searchValue;
+  nsCString searchValue = NS_ConvertUTF16toUTF8(aSearchValue);
+  MsgCompressWhitespace(searchValue);
 
   if (mTree) {
     mTree->BeginUpdateBatch();
     mTree->RowCountChanged(0, -mSubscribeSearchResult.Length());
   }
 
+  nsTArray<nsCString> searchStringParts;
+  if (!searchValue.IsEmpty())
+    ParseString(searchValue, ' ', searchStringParts);
+
   mSubscribeSearchResult.Clear();
   uint32_t length = mGroupsOnServer.Length();
   for (uint32_t i = 0; i < length; i++)
   {
-    if (CaseInsensitiveFindInReadable(mSearchValue, NS_ConvertUTF8toUTF16(mGroupsOnServer[i])))
+    // check that all parts of the search string occur
+    bool found = true;
+    for (uint32_t j = 0; j < searchStringParts.Length(); ++j) {
+      if (MsgFind(mGroupsOnServer[i], searchStringParts[j], true, 0) == kNotFound) {
+        found = false;
+        break;
+      }
+    }
+
+    if (found)
       mSubscribeSearchResult.AppendElement(mGroupsOnServer[i]);
   }
 
@@ -1730,7 +1745,7 @@ nsNntpIncomingServer::GetCellProperties(int32_t row, nsITreeColumn* col, nsAStri
         // in the "subscribedCol"
         if (mSearchResultSortDescending)
           row = mSubscribeSearchResult.Length() - 1 - row;
-        if (mTempSubscribed.IndexOf(mSubscribeSearchResult.ElementAt(row)) != mTempSubscribed.NoIndex) {
+        if (mTempSubscribed.Contains(mSubscribeSearchResult.ElementAt(row))) {
           properties.AssignLiteral("subscribed");
         }
     }
