@@ -19,7 +19,6 @@
 #include "nsNetscapeProfileMigratorBase.h"
 #include "nsNetUtil.h"
 #include "prtime.h"
-#include "nsILoginManagerStorage.h"
 #include "nsINIParser.h"
 #include "nsArrayUtils.h"
 
@@ -61,7 +60,7 @@ nsNetscapeProfileMigratorBase::GetSourceExists(bool* aResult)
   GetSourceProfiles(getter_AddRefs(profiles));
 
   if (profiles) {
-    PRUint32 count;
+    uint32_t count;
     profiles->GetLength(&count);
     *aResult = count > 0;
   }
@@ -78,7 +77,7 @@ nsNetscapeProfileMigratorBase::GetSourceHasMultipleProfiles(bool* aResult)
   GetSourceProfiles(getter_AddRefs(profiles));
 
   if (profiles) {
-    PRUint32 count;
+    uint32_t count;
     profiles->GetLength(&count);
     *aResult = count > 1;
   }
@@ -155,7 +154,7 @@ nsNetscapeProfileMigratorBase::CopyHomePageData(bool aReplace)
   mTargetProfile->Clone(getter_AddRefs(targetPrefsFile));
   targetPrefsFile->AppendNative(nsDependentCString(FILE_NAME_PREFS));
 
-  // Don't use nsnull here as we're too early in the cycle for the prefs
+  // Don't use nullptr here as we're too early in the cycle for the prefs
   // service to get its default file (because the NS_GetDirectoryService items
   // aren't fully set up yet).
   psvc->ReadUserPrefs(targetPrefsFile);
@@ -297,9 +296,9 @@ nsNetscapeProfileMigratorBase::SetCookie(PrefTransform* aTransform,
 nsresult
 nsNetscapeProfileMigratorBase::GetSourceProfile(const PRUnichar* aProfile)
 {
-  PRUint32 count;
+  uint32_t count;
   mProfileNames->GetLength(&count);
-  for (PRUint32 i = 0; i < count; ++i) {
+  for (uint32_t i = 0; i < count; ++i) {
     nsCOMPtr<nsISupportsString> str(do_QueryElementAt(mProfileNames, i));
     nsString profileName;
     str->GetData(profileName);
@@ -337,12 +336,12 @@ nsNetscapeProfileMigratorBase::GetProfileDataFromProfilesIni(nsIFile* aDataDir,
   rv = parser.Init(profileIni);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCAutoString buffer, filePath;
+  nsAutoCString buffer, filePath;
   bool isRelative;
 
   unsigned int c = 0;
   for (c = 0; true; ++c) {
-    nsCAutoString profileID("Profile");
+    nsAutoCString profileID("Profile");
     profileID.AppendInt(c);
 
     rv = parser.GetString(profileID.get(), "IsRelative", buffer);
@@ -504,17 +503,17 @@ nsNetscapeProfileMigratorBase::ReadBranch(const char * branchName,
   nsCOMPtr<nsIPrefBranch> branch;
   aPrefService->GetBranch(branchName, getter_AddRefs(branch));
 
-  PRUint32 count;
-  char** prefs = nsnull;
+  uint32_t count;
+  char** prefs = nullptr;
 
   nsresult rv = branch->GetChildList("", &count, &prefs);
   if (NS_FAILED(rv))
     return;
 
-  for (PRUint32 i = 0; i < count; ++i) {
+  for (uint32_t i = 0; i < count; ++i) {
     // Save each pref's value into an array
     char* currPref = prefs[i];
-    PRInt32 type;
+    int32_t type;
     branch->GetPrefType(currPref, &type);
 
     PrefBranchStruct* pref = new PrefBranchStruct;
@@ -555,15 +554,15 @@ nsNetscapeProfileMigratorBase::WriteBranch(const char * branchName,
   nsCOMPtr<nsIPrefBranch> branch;
   aPrefService->GetBranch(branchName, getter_AddRefs(branch));
 
-  PRUint32 count = aPrefs.Length();
-  for (PRUint32 i = 0; i < count; ++i) {
+  uint32_t count = aPrefs.Length();
+  for (uint32_t i = 0; i < count; ++i) {
     PrefBranchStruct* pref = aPrefs.ElementAt(i);
 
     switch (pref->type) {
     case nsIPrefBranch::PREF_STRING:
       branch->SetCharPref(pref->prefName, pref->stringValue);
       NS_Free(pref->stringValue);
-      pref->stringValue = nsnull;
+      pref->stringValue = nullptr;
       break;
     case nsIPrefBranch::PREF_BOOL:
       branch->SetBoolPref(pref->prefName, pref->boolValue);
@@ -577,9 +576,9 @@ nsNetscapeProfileMigratorBase::WriteBranch(const char * branchName,
       break;
     }
     NS_Free(pref->prefName);
-    pref->prefName = nsnull;
+    pref->prefName = nullptr;
     delete pref;
-    pref = nsnull;
+    pref = nullptr;
   }
   aPrefs.Clear();
 }
@@ -642,27 +641,6 @@ nsNetscapeProfileMigratorBase::CopyCookies(bool aReplace)
   return cookieManager->ImportCookies(seamonkeyCookiesFile);
 }
 
-nsresult
-nsNetscapeProfileMigratorBase::CopyPasswords(bool aReplace)
-{
-  nsCString signonsFileName;
-  GetSignonFileName(aReplace, getter_Copies(signonsFileName));
-
-  if (signonsFileName.IsEmpty())
-    return NS_ERROR_FILE_NOT_FOUND;
-
-  if (aReplace)
-    return CopyFile(signonsFileName.get(), signonsFileName.get());
-
-  nsCOMPtr<nsIFile> seamonkeyPasswordsFile;
-  mSourceProfile->Clone(getter_AddRefs(seamonkeyPasswordsFile));
-  seamonkeyPasswordsFile->AppendNative(signonsFileName);
-
-  nsCOMPtr<nsILoginManagerStorage>
-      lms(do_GetService("@mozilla.org/login-manager/storage/mozStorage;1"));
-  return lms->InitWithFile(seamonkeyPasswordsFile, nsnull);
-}
-
 nsresult
 nsNetscapeProfileMigratorBase::CopyUserSheet(const char* aFileName)
 {
@@ -691,64 +669,6 @@ nsNetscapeProfileMigratorBase::CopyUserSheet(const char* aFileName)
                                          nsDependentCString(aFileName));
 }
 
-nsresult
-nsNetscapeProfileMigratorBase::GetSignonFileName(bool aReplace,
-                                                 char** aFileName)
-{
-  if (aReplace) {
-    // Find out what the signons file was called, this is stored in a pref
-    // in Seamonkey.
-    nsCOMPtr<nsIPrefService> psvc(do_GetService(NS_PREFSERVICE_CONTRACTID));
-
-    if (psvc) {
-      nsCOMPtr<nsIPrefBranch> branch(do_QueryInterface(psvc));
-
-      if (NS_SUCCEEDED(branch->GetCharPref("signon.SignonFileName",
-                                           aFileName)))
-        return NS_OK;
-    }
-  }
-
-  nsCOMPtr<nsISimpleEnumerator> entries;
-  nsresult rv = mSourceProfile->GetDirectoryEntries(getter_AddRefs(entries));
-  if (NS_FAILED(rv))
-    return rv;
-
-  nsCAutoString fileName;
-  while (1) {
-    bool hasMore = false;
-    rv = entries->HasMoreElements(&hasMore);
-    if (NS_FAILED(rv) || !hasMore)
-      break;
-
-    nsCOMPtr<nsISupports> supp;
-    rv = entries->GetNext(getter_AddRefs(supp));
-    if (NS_FAILED(rv))
-      break;
-
-    nsCOMPtr<nsIFile> currFile(do_QueryInterface(supp));
-
-    nsCOMPtr<nsIURI> uri;
-    rv = NS_NewFileURI(getter_AddRefs(uri), currFile);
-    if (NS_FAILED(rv))
-      break;
-
-    nsCOMPtr<nsIURL> url(do_QueryInterface(uri));
-
-    nsCAutoString extn;
-    url->GetFileExtension(extn);
-
-    if (extn.Equals("s", CaseInsensitiveCompare)) {
-      url->GetFileName(fileName);
-      break;
-    }
-  };
-
-  *aFileName = ToNewCString(fileName);
-
-  return NS_OK;
-}
-
 ///////////////////////////////////////////////////////////////////////////////
 // Browser Import Functions
 
@@ -767,8 +687,6 @@ nsNetscapeProfileMigratorBase::CopyOtherData(bool aReplace)
   if (!aReplace)
     return NS_OK;
 
-  nsresult rv = CopyFile(FILE_NAME_SEARCH, FILE_NAME_SEARCH);
-
   nsCOMPtr<nsIFile> sourceSearchDir;
   mSourceProfile->Clone(getter_AddRefs(sourceSearchDir));
   sourceSearchDir->AppendNative(nsDependentCString(DIR_NAME_SEARCH));
@@ -777,9 +695,11 @@ nsNetscapeProfileMigratorBase::CopyOtherData(bool aReplace)
   mTargetProfile->Clone(getter_AddRefs(targetSearchDir));
   targetSearchDir->AppendNative(nsDependentCString(DIR_NAME_SEARCH));
 
-  rv = rv | RecursiveCopy(sourceSearchDir, targetSearchDir);
+  nsresult rv = RecursiveCopy(sourceSearchDir, targetSearchDir);
+  if (NS_FAILED(rv))
+    return rv;
 
-  return rv | CopyFile(FILE_NAME_DOWNLOADS, FILE_NAME_DOWNLOADS);
+  return CopyFile(FILE_NAME_DOWNLOADS, FILE_NAME_DOWNLOADS);
 }
 
 nsresult
@@ -807,8 +727,8 @@ nsNetscapeProfileMigratorBase::CopyAddressBookDirectories(PBStructArray &aLdapSe
   index.AppendInt(nsISuiteProfileMigrator::ADDRESSBOOK_DATA);
   NOTIFY_OBSERVERS(MIGRATION_ITEMBEFOREMIGRATE, index.get());
 
-  PRUint32 count = aLdapServers.Length();
-  for (PRUint32 i = 0; i < count; ++i) {
+  uint32_t count = aLdapServers.Length();
+  for (uint32_t i = 0; i < count; ++i) {
     PrefBranchStruct* pref = aLdapServers.ElementAt(i);
     nsDependentCString prefName(pref->prefName);
 
@@ -830,8 +750,8 @@ nsNetscapeProfileMigratorBase::CopySignatureFiles(PBStructArray &aIdentities,
 {
   nsresult rv = NS_OK;
 
-  PRUint32 count = aIdentities.Length();
-  for (PRUint32 i = 0; i < count; ++i)
+  uint32_t count = aIdentities.Length();
+  for (uint32_t i = 0; i < count; ++i)
   {
     PrefBranchStruct* pref = aIdentities.ElementAt(i);
     nsDependentCString prefName(pref->prefName);
@@ -864,7 +784,7 @@ nsNetscapeProfileMigratorBase::CopySignatureFiles(PBStructArray &aIdentities,
         targetSigFile->Append(leafName);
 
         // now write out the new descriptor
-        nsCAutoString descriptorString;
+        nsAutoCString descriptorString;
         targetSigFile->GetPersistentDescriptor(descriptorString);
         NS_Free(pref->stringValue);
         pref->stringValue = ToNewCString(descriptorString);
@@ -892,8 +812,8 @@ nsNetscapeProfileMigratorBase::CopyMailFolderPrefs(PBStructArray &aMailServers,
   //     destination directory pref
   CopyFile(FILE_NAME_VIRTUALFOLDERS, FILE_NAME_VIRTUALFOLDERS);
 
-  PRInt32 count = aMailServers.Length();
-  for (PRInt32 i = 0; i < count; ++i) {
+  int32_t count = aMailServers.Length();
+  for (int32_t i = 0; i < count; ++i) {
     PrefBranchStruct* pref = aMailServers.ElementAt(i);
     nsDependentCString prefName(pref->prefName);
 
@@ -951,7 +871,7 @@ nsNetscapeProfileMigratorBase::CopyMailFolderPrefs(PBStructArray &aMailServers,
         // now we want to make sure the actual directory pref that gets
         // transformed into the new profile's pref.js has the right file
         // location.
-        nsCAutoString descriptorString;
+        nsAutoCString descriptorString;
         targetMailFolder->GetPersistentDescriptor(descriptorString);
         NS_Free(pref->stringValue);
         pref->stringValue = ToNewCString(descriptorString);
@@ -982,7 +902,7 @@ nsNetscapeProfileMigratorBase::CopyMailFolderPrefs(PBStructArray &aMailServers,
         targetNewsRCFile->Append(leafName);
 
         // now write out the new descriptor
-        nsCAutoString descriptorString;
+        nsAutoCString descriptorString;
         targetNewsRCFile->GetPersistentDescriptor(descriptorString);
         NS_Free(pref->stringValue);
         pref->stringValue = ToNewCString(descriptorString);
@@ -992,7 +912,7 @@ nsNetscapeProfileMigratorBase::CopyMailFolderPrefs(PBStructArray &aMailServers,
 
   // Remove all .directory-rel prefs as those might have changed; MailNews
   // will create those prefs again on first use
-  for (PRInt32 i = count; i-- > 0; ) {
+  for (int32_t i = count; i-- > 0; ) {
     PrefBranchStruct* pref = aMailServers.ElementAt(i);
     nsDependentCString prefName(pref->prefName);
 
@@ -1016,13 +936,13 @@ nsNetscapeProfileMigratorBase::CopyMailFolders()
 
   // Generate the max progress value now that we know all of the files we
   // need to copy
-  PRUint32 count = mFileCopyTransactions.Length();
+  uint32_t count = mFileCopyTransactions.Length();
   mMaxProgress = 0;
   mCurrentProgress = 0;
 
-  for (PRUint32 i = 0; i < count; ++i) {
+  for (uint32_t i = 0; i < count; ++i) {
     fileTransactionEntry fileTransaction = mFileCopyTransactions[i];
-    PRInt64 fileSize;
+    int64_t fileSize;
     fileTransaction.srcFile->GetFileSize(&fileSize);
     LL_ADD(mMaxProgress, mMaxProgress, fileSize);
   }
@@ -1034,7 +954,7 @@ void
 nsNetscapeProfileMigratorBase::CopyNextFolder()
 {
   if (mFileCopyTransactionIndex < mFileCopyTransactions.Length()) {
-    PRUint32 percentage = 0;
+    uint32_t percentage = 0;
     fileTransactionEntry fileTransaction =
       mFileCopyTransactions.ElementAt(mFileCopyTransactionIndex++);
 
@@ -1043,11 +963,11 @@ nsNetscapeProfileMigratorBase::CopyNextFolder()
                                     EmptyString());
 
     // add to our current progress
-    PRInt64 fileSize;
+    int64_t fileSize;
     fileTransaction.srcFile->GetFileSize(&fileSize);
     LL_ADD(mCurrentProgress, mCurrentProgress, fileSize);
 
-    PRInt64 percentDone;
+    int64_t percentDone;
     LL_MUL(percentDone, mCurrentProgress, 100);
 
     LL_DIV(percentDone, percentDone, mMaxProgress);
@@ -1089,5 +1009,5 @@ nsNetscapeProfileMigratorBase::EndCopyFolders()
   index.AppendInt(nsISuiteProfileMigrator::MAILDATA);
   NOTIFY_OBSERVERS(MIGRATION_ITEMAFTERMIGRATE, index.get());
 
-  NOTIFY_OBSERVERS(MIGRATION_ENDED, nsnull);
+  NOTIFY_OBSERVERS(MIGRATION_ENDED, nullptr);
 }
